@@ -45,7 +45,6 @@ var All = map[string]Group{
 		Label: "Circumvention Tools",
 		Nettests: []Nettest{
 			Psiphon{},
-			RiseupVPN{},
 			Tor{},
 		},
 		UnattendedOK: true,
@@ -55,6 +54,7 @@ var All = map[string]Group{
 		Nettests: []Nettest{
 			DNSCheck{},
 			STUNReachability{},
+			TorSf{},
 		},
 	},
 }
