@@ -4,20 +4,22 @@ package uncensored
 
 import (
 	"context"
+	"errors"
 	"net"
 	"net/http"
 
 	"github.com/apex/log"
 	"github.com/ooni/probe-cli/v3/internal/engine/experiment/urlgetter"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx"
-	"github.com/ooni/probe-cli/v3/internal/engine/runtimex"
+	"github.com/ooni/probe-cli/v3/internal/model"
+	"github.com/ooni/probe-cli/v3/internal/runtimex"
 )
 
 // Client is DNS, HTTP, and TCP client.
 type Client struct {
-	dnsClient     *netx.DNSClient
-	httpTransport netx.HTTPRoundTripper
-	dialer        netx.Dialer
+	dnsClient     model.Resolver
+	httpTransport model.HTTPTransport
+	dialer        model.Dialer
 }
 
 // NewClient creates a new Client.
@@ -32,7 +34,7 @@ func NewClient(resolverURL string) (*Client, error) {
 		return nil, err
 	}
 	return &Client{
-		dnsClient:     &configuration.DNSClient,
+		dnsClient:     configuration.DNSClient,
 		httpTransport: netx.NewHTTPTransport(configuration.HTTPConfig),
 		dialer:        netx.NewDialer(configuration.HTTPConfig),
 	}, nil
@@ -48,39 +50,44 @@ func Must(client *Client, err error) *Client {
 // DefaultClient is the default client for DNS, HTTP, and TCP.
 var DefaultClient = Must(NewClient(""))
 
-var _ netx.Resolver = DefaultClient
+var _ model.Resolver = DefaultClient
 
-// Address implements netx.Resolver.Address
+// Address implements Resolver.Address
 func (c *Client) Address() string {
 	return c.dnsClient.Address()
 }
 
-// LookupHost implements netx.Resolver.LookupHost
+// LookupHost implements Resolver.LookupHost
 func (c *Client) LookupHost(ctx context.Context, domain string) ([]string, error) {
 	return c.dnsClient.LookupHost(ctx, domain)
 }
 
-// Network implements netx.Resolver.Network
+// LookupHTTPS implements model.Resolver.LookupHTTPS.
+func (c *Client) LookupHTTPS(ctx context.Context, domain string) (*model.HTTPSSvc, error) {
+	return nil, errors.New("not implemented")
+}
+
+// Network implements Resolver.Network
 func (c *Client) Network() string {
 	return c.dnsClient.Network()
 }
 
-var _ netx.Dialer = DefaultClient
+var _ model.Dialer = DefaultClient
 
-// DialContext implements netx.Dialer.DialContext
+// DialContext implements Dialer.DialContext
 func (c *Client) DialContext(ctx context.Context, network, address string) (net.Conn, error) {
 	return c.dialer.DialContext(ctx, network, address)
 }
 
-var _ netx.HTTPRoundTripper = DefaultClient
+var _ model.HTTPTransport = DefaultClient
 
-// CloseIdleConnections implement netx.HTTPRoundTripper.CloseIdleConnections
+// CloseIdleConnections implement HTTPRoundTripper.CloseIdleConnections
 func (c *Client) CloseIdleConnections() {
 	c.dnsClient.CloseIdleConnections()
 	c.httpTransport.CloseIdleConnections()
 }
 
-// RoundTrip implement netx.HTTPRoundTripper.RoundTrip
+// RoundTrip implement HTTPRoundTripper.RoundTrip
 func (c *Client) RoundTrip(req *http.Request) (*http.Response, error) {
 	return c.httpTransport.RoundTrip(req)
 }
