@@ -5,7 +5,6 @@ import (
 	"errors"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"math/rand"
 	"net/url"
 	"os"
@@ -17,10 +16,13 @@ import (
 
 	"github.com/apex/log"
 	"github.com/ooni/probe-cli/v3/internal/engine"
-	"github.com/ooni/probe-cli/v3/internal/engine/humanizex"
 	"github.com/ooni/probe-cli/v3/internal/engine/legacy/assetsdir"
-	"github.com/ooni/probe-cli/v3/internal/engine/model"
-	"github.com/ooni/probe-cli/v3/internal/engine/netx/selfcensor"
+	"github.com/ooni/probe-cli/v3/internal/humanize"
+	"github.com/ooni/probe-cli/v3/internal/kvstore"
+	"github.com/ooni/probe-cli/v3/internal/model"
+	"github.com/ooni/probe-cli/v3/internal/netxlite"
+	"github.com/ooni/probe-cli/v3/internal/netxlite/filtering"
+	"github.com/ooni/probe-cli/v3/internal/runtimex"
 	"github.com/ooni/probe-cli/v3/internal/version"
 	"github.com/pborman/getopt/v2"
 )
@@ -28,6 +30,7 @@ import (
 // Options contains the options you can set from the CLI.
 type Options struct {
 	Annotations      []string
+	Censor           string
 	ExtraOptions     []string
 	HomeDir          string
 	Inputs           []string
@@ -40,7 +43,6 @@ type Options struct {
 	Proxy            string
 	Random           bool
 	ReportFile       string
-	SelfCensorSpec   string
 	TorArgs          []string
 	TorBinary        string
 	Tunnel           string
@@ -63,6 +65,10 @@ func init() {
 	getopt.FlagLong(
 		&globalOptions.Annotations, "annotation", 'A', "Add annotaton", "KEY=VALUE",
 	)
+	getopt.FlagLong(
+		&globalOptions.Censor, "censor", 0,
+		"Specifies censorship rules to apply for QA purposes", "FILE",
+	)
 	getopt.FlagLong(
 		&globalOptions.ExtraOptions, "option", 'O',
 		"Pass an option to the experiment", "KEY=VALUE",
@@ -107,10 +113,6 @@ func init() {
 		&globalOptions.ReportFile, "reportfile", 'o',
 		"Set the report file path", "PATH",
 	)
-	getopt.FlagLong(
-		&globalOptions.SelfCensorSpec, "self-censor-spec", 0,
-		"Enable and configure self censorship", "JSON",
-	)
 	getopt.FlagLong(
 		&globalOptions.TorArgs, "tor-args", 0,
 		"Extra args for tor binary (may be specified multiple times)",
@@ -157,6 +159,7 @@ func Main() {
 		os.Exit(0)
 	}
 	fatalIfFalse(len(getopt.Args()) == 1, "Missing experiment name")
+	fatalOnError(engine.CheckEmbeddedPsiphonConfig(), "Invalid embedded psiphon config")
 	MainWithConfiguration(getopt.Arg(0), globalOptions)
 }
 
@@ -263,7 +266,7 @@ func canOpen(filepath string) bool {
 
 func maybeWriteConsentFile(yes bool, filepath string) (err error) {
 	if yes {
-		err = ioutil.WriteFile(filepath, []byte("\n"), 0644)
+		err = os.WriteFile(filepath, []byte("\n"), 0644)
 	}
 	return
 }
@@ -304,9 +307,6 @@ func MainWithConfiguration(experimentName string, currentOptions Options) {
 	extraOptions := mustMakeMap(currentOptions.ExtraOptions)
 	annotations := mustMakeMap(currentOptions.Annotations)
 
-	err := selfcensor.MaybeEnable(currentOptions.SelfCensorSpec)
-	fatalOnError(err, "cannot parse --self-censor-spec argument")
-
 	logger := &log.Logger{Level: log.InfoLevel, Handler: &logHandler{Writer: os.Stderr}}
 	if currentOptions.Verbose {
 		logger.Level = log.DebugLevel
@@ -316,13 +316,24 @@ func MainWithConfiguration(experimentName string, currentOptions Options) {
 	}
 	log.Log = logger
 
+	if currentOptions.Censor != "" {
+		config, err := filtering.NewTProxyConfig(currentOptions.Censor)
+		runtimex.PanicOnError(err, "cannot parse --censor file as JSON")
+		tproxy, err := filtering.NewTProxy(config, log.Log)
+		runtimex.PanicOnError(err, "cannot create tproxy instance")
+		defer tproxy.Close()
+		netxlite.TProxy = tproxy
+		log.Infof("miniooni: disabling submission with --censor to avoid pulluting OONI data")
+		currentOptions.NoCollector = true
+	}
+
 	//Mon Jan 2 15:04:05 -0700 MST 2006
 	log.Infof("Current time: %s", time.Now().Format("2006-01-02 15:04:05 MST"))
 
 	homeDir := gethomedir(currentOptions.HomeDir)
 	fatalIfFalse(homeDir != "", "home directory is empty")
 	miniooniDir := path.Join(homeDir, ".miniooni")
-	err = os.MkdirAll(miniooniDir, 0700)
+	err := os.MkdirAll(miniooniDir, 0700)
 	fatalOnError(err, "cannot create $HOME/.miniooni directory")
 
 	// We cleanup the assets files used by versions of ooniprobe
@@ -348,7 +359,7 @@ func MainWithConfiguration(experimentName string, currentOptions Options) {
 	}
 
 	kvstore2dir := filepath.Join(miniooniDir, "kvstore2")
-	kvstore, err := engine.NewFileSystemKVStore(kvstore2dir)
+	kvstore, err := kvstore.NewFS(kvstore2dir)
 	fatalOnError(err, "cannot create kvstore2 directory")
 
 	tunnelDir := filepath.Join(miniooniDir, "tunnel")
@@ -366,7 +377,7 @@ func MainWithConfiguration(experimentName string, currentOptions Options) {
 		TunnelDir:       tunnelDir,
 	}
 	if currentOptions.ProbeServicesURL != "" {
-		config.AvailableProbeServices = []model.Service{{
+		config.AvailableProbeServices = []model.OOAPIService{{
 			Address: currentOptions.ProbeServicesURL,
 			Type:    "https",
 		}}
@@ -377,8 +388,8 @@ func MainWithConfiguration(experimentName string, currentOptions Options) {
 	defer func() {
 		sess.Close()
 		log.Infof("whole session: recv %s, sent %s",
-			humanizex.SI(sess.KibiBytesReceived()*1024, "byte"),
-			humanizex.SI(sess.KibiBytesSent()*1024, "byte"),
+			humanize.SI(sess.KibiBytesReceived()*1024, "byte"),
+			humanize.SI(sess.KibiBytesSent()*1024, "byte"),
 		)
 	}()
 	log.Debugf("miniooni temporary directory: %s", sess.TempDir())
@@ -400,15 +411,16 @@ func MainWithConfiguration(experimentName string, currentOptions Options) {
 	fatalOnError(err, "cannot create experiment builder")
 
 	inputLoader := &engine.InputLoader{
-		CheckInConfig: &model.CheckInConfig{
+		CheckInConfig: &model.OOAPICheckInConfig{
 			RunType:  "manual",
 			OnWiFi:   true, // meaning: not on 4G
 			Charging: true,
 		},
-		InputPolicy:  builder.InputPolicy(),
-		StaticInputs: currentOptions.Inputs,
-		SourceFiles:  currentOptions.InputFilePaths,
-		Session:      sess,
+		ExperimentName: experimentName,
+		InputPolicy:    builder.InputPolicy(),
+		StaticInputs:   currentOptions.Inputs,
+		SourceFiles:    currentOptions.InputFilePaths,
+		Session:        sess,
 	}
 	inputs, err := inputLoader.Load(context.Background())
 	fatalOnError(err, "cannot load inputs")
@@ -426,8 +438,8 @@ func MainWithConfiguration(experimentName string, currentOptions Options) {
 	experiment := builder.NewExperiment()
 	defer func() {
 		log.Infof("experiment: recv %s, sent %s",
-			humanizex.SI(experiment.KibiBytesReceived()*1024, "byte"),
-			humanizex.SI(experiment.KibiBytesSent()*1024, "byte"),
+			humanize.SI(experiment.KibiBytesReceived()*1024, "byte"),
+			humanize.SI(experiment.KibiBytesSent()*1024, "byte"),
 		)
 	}()
 
@@ -469,15 +481,12 @@ type experimentWrapper struct {
 	total int
 }
 
-func (ew *experimentWrapper) MeasureWithContext(
-	ctx context.Context, idx int, input string) (*model.Measurement, error) {
+func (ew *experimentWrapper) MeasureAsync(
+	ctx context.Context, input string, idx int) (<-chan *model.Measurement, error) {
 	if input != "" {
 		log.Infof("[%d/%d] running with input: %s", idx+1, ew.total, input)
 	}
-	measurement, err := ew.child.MeasureWithContext(ctx, idx, input)
-	warnOnError(err, "measurement failed")
-	// policy: we do not stop the loop if the measurement fails
-	return measurement, nil
+	return ew.child.MeasureAsync(ctx, input, idx)
 }
 
 type submitterWrapper struct {
