@@ -20,8 +20,10 @@ import (
 	"github.com/ooni/probe-cli/v3/internal/engine/experiment/telegram"
 	"github.com/ooni/probe-cli/v3/internal/engine/experiment/tlstool"
 	"github.com/ooni/probe-cli/v3/internal/engine/experiment/tor"
+	"github.com/ooni/probe-cli/v3/internal/engine/experiment/torsf"
 	"github.com/ooni/probe-cli/v3/internal/engine/experiment/urlgetter"
 	"github.com/ooni/probe-cli/v3/internal/engine/experiment/webconnectivity"
+	"github.com/ooni/probe-cli/v3/internal/engine/experiment/webstepsx"
 	"github.com/ooni/probe-cli/v3/internal/engine/experiment/whatsapp"
 )
 
@@ -47,7 +49,7 @@ var experimentsByName = map[string]func(*Session) *ExperimentBuilder{
 				))
 			},
 			config:      &dnscheck.Config{},
-			inputPolicy: InputStrictlyRequired,
+			inputPolicy: InputOrStaticDefault,
 		}
 	},
 
@@ -67,59 +69,6 @@ var experimentsByName = map[string]func(*Session) *ExperimentBuilder{
 		}
 	},
 
-	"example_with_input": func(session *Session) *ExperimentBuilder {
-		return &ExperimentBuilder{
-			build: func(config interface{}) *Experiment {
-				return NewExperiment(session, example.NewExperimentMeasurer(
-					*config.(*example.Config), "example_with_input",
-				))
-			},
-			config: &example.Config{
-				Message:   "Good day from the example with input experiment!",
-				SleepTime: int64(time.Second),
-			},
-			interruptible: true,
-			inputPolicy:   InputStrictlyRequired,
-		}
-	},
-
-	// TODO(bassosimone): when we can set experiment options using the JSON
-	// we need to get rid of all these multiple experiments.
-	//
-	// See https://github.com/ooni/probe-engine/issues/413
-	"example_with_input_non_interruptible": func(session *Session) *ExperimentBuilder {
-		return &ExperimentBuilder{
-			build: func(config interface{}) *Experiment {
-				return NewExperiment(session, example.NewExperimentMeasurer(
-					*config.(*example.Config), "example_with_input_non_interruptible",
-				))
-			},
-			config: &example.Config{
-				Message:   "Good day from the example with input experiment!",
-				SleepTime: int64(time.Second),
-			},
-			interruptible: false,
-			inputPolicy:   InputStrictlyRequired,
-		}
-	},
-
-	"example_with_failure": func(session *Session) *ExperimentBuilder {
-		return &ExperimentBuilder{
-			build: func(config interface{}) *Experiment {
-				return NewExperiment(session, example.NewExperimentMeasurer(
-					*config.(*example.Config), "example_with_failure",
-				))
-			},
-			config: &example.Config{
-				Message:     "Good day from the example with failure experiment!",
-				ReturnError: true,
-				SleepTime:   int64(time.Second),
-			},
-			interruptible: true,
-			inputPolicy:   InputNone,
-		}
-	},
-
 	"facebook_messenger": func(session *Session) *ExperimentBuilder {
 		return &ExperimentBuilder{
 			build: func(config interface{}) *Experiment {
@@ -249,7 +198,7 @@ var experimentsByName = map[string]func(*Session) *ExperimentBuilder{
 				))
 			},
 			config:      &stunreachability.Config{},
-			inputPolicy: InputOptional,
+			inputPolicy: InputOrStaticDefault,
 		}
 	},
 
@@ -289,6 +238,18 @@ var experimentsByName = map[string]func(*Session) *ExperimentBuilder{
 		}
 	},
 
+	"torsf": func(session *Session) *ExperimentBuilder {
+		return &ExperimentBuilder{
+			build: func(config interface{}) *Experiment {
+				return NewExperiment(session, torsf.NewExperimentMeasurer(
+					*config.(*torsf.Config),
+				))
+			},
+			config:      &torsf.Config{},
+			inputPolicy: InputNone,
+		}
+	},
+
 	"urlgetter": func(session *Session) *ExperimentBuilder {
 		return &ExperimentBuilder{
 			build: func(config interface{}) *Experiment {
@@ -313,6 +274,18 @@ var experimentsByName = map[string]func(*Session) *ExperimentBuilder{
 		}
 	},
 
+	"websteps": func(session *Session) *ExperimentBuilder {
+		return &ExperimentBuilder{
+			build: func(config interface{}) *Experiment {
+				return NewExperiment(session, webstepsx.NewExperimentMeasurer(
+					*config.(*webstepsx.Config),
+				))
+			},
+			config:      &webstepsx.Config{},
+			inputPolicy: InputOrQueryBackend,
+		}
+	},
+
 	"whatsapp": func(session *Session) *ExperimentBuilder {
 		return &ExperimentBuilder{
 			build: func(config interface{}) *Experiment {
