@@ -8,7 +8,7 @@ import (
 	"net/http"
 	"net/url"
 
-	"github.com/ooni/probe-cli/v3/internal/engine/model"
+	"github.com/ooni/probe-cli/v3/internal/model"
 )
 
 type collectDeps interface {
@@ -16,7 +16,7 @@ type collectDeps interface {
 	JSONMarshal(v interface{}) ([]byte, error)
 	Logger() model.Logger
 	NewHTTPRequest(method string, url string, body io.Reader) (*http.Request, error)
-	ReadAll(r io.Reader) ([]byte, error)
+	ReadAllContext(ctx context.Context, r io.Reader) ([]byte, error)
 	Scheme() string
 	UserAgent() string
 }
@@ -47,7 +47,7 @@ func collect(ctx context.Context, fqdn, authorization string,
 		return errHTTPRequestFailed
 	}
 	defer resp.Body.Close()
-	data, err = deps.ReadAll(resp.Body)
+	data, err = deps.ReadAllContext(ctx, resp.Body)
 	if err != nil {
 		return err
 	}
