@@ -11,15 +11,15 @@ import (
 	"net/url"
 	"strings"
 	"sync"
-	"sync/atomic"
 	"time"
 
+	"github.com/ooni/probe-cli/v3/internal/atomicx"
 	"github.com/ooni/probe-cli/v3/internal/engine/experiment/urlgetter"
-	"github.com/ooni/probe-cli/v3/internal/engine/model"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx/archival"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx/trace"
-	"github.com/ooni/probe-cli/v3/internal/engine/runtimex"
+	"github.com/ooni/probe-cli/v3/internal/model"
+	"github.com/ooni/probe-cli/v3/internal/runtimex"
 )
 
 const (
@@ -31,7 +31,7 @@ const (
 // Endpoints keeps track of repeatedly measured endpoints.
 type Endpoints struct {
 	WaitTime  time.Duration
-	count     uint32
+	count     *atomicx.Int64
 	nextVisit map[string]time.Time
 	mu        sync.Mutex
 }
@@ -48,7 +48,10 @@ func (e *Endpoints) maybeSleep(resolverURL string, logger model.Logger) {
 		return
 	}
 	sleepTime := nextTime.Sub(now)
-	atomic.AddUint32(&e.count, 1)
+	if e.count == nil {
+		e.count = &atomicx.Int64{}
+	}
+	e.count.Add(1)
 	logger.Infof("waiting %v before testing %s again", sleepTime, resolverURL)
 	time.Sleep(sleepTime)
 }
@@ -156,6 +159,9 @@ func (m *Measurer) Run(
 		return ErrUnsupportedURLScheme
 	}
 
+	// Implementation note: we must not return an error from now now. Returning an
+	// error means that we don't have a measurement to submit.
+
 	// 4. possibly expand a domain to a list of IP addresses.
 	//
 	// Implementation note: because the resolver we constructed also deals
@@ -228,7 +234,7 @@ func (m *Measurer) Run(
 	return nil
 }
 
-func (m *Measurer) lookupHost(ctx context.Context, hostname string, r netx.Resolver) ([]string, error) {
+func (m *Measurer) lookupHost(ctx context.Context, hostname string, r model.Resolver) ([]string, error) {
 	ctx, cancel := context.WithTimeout(ctx, 20*time.Second)
 	defer cancel()
 	return r.LookupHost(ctx, hostname)
