@@ -2,15 +2,13 @@ package run
 
 import (
 	"context"
-	"sync"
 
 	"github.com/ooni/probe-cli/v3/internal/engine/experiment/dnscheck"
-	"github.com/ooni/probe-cli/v3/internal/engine/model"
+	"github.com/ooni/probe-cli/v3/internal/model"
 )
 
 type dnsCheckMain struct {
 	Endpoints *dnscheck.Endpoints
-	mu        sync.Mutex
 }
 
 func (m *dnsCheckMain) do(ctx context.Context, input StructuredInput,
