@@ -5,22 +5,23 @@ package stunreachability
 
 import (
 	"context"
+	"errors"
 	"fmt"
 	"net"
+	"net/url"
 	"time"
 
-	"github.com/ooni/probe-cli/v3/internal/engine/model"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx/archival"
-	"github.com/ooni/probe-cli/v3/internal/engine/netx/dialer"
-	"github.com/ooni/probe-cli/v3/internal/engine/netx/errorx"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx/trace"
+	"github.com/ooni/probe-cli/v3/internal/model"
+	"github.com/ooni/probe-cli/v3/internal/netxlite"
 	"github.com/pion/stun"
 )
 
 const (
 	testName    = "stunreachability"
-	testVersion = "0.2.0"
+	testVersion = "0.4.0"
 )
 
 // Config contains the experiment config.
@@ -58,12 +59,21 @@ func (m *Measurer) ExperimentVersion() string {
 }
 
 func wrap(err error) error {
-	return errorx.SafeErrWrapperBuilder{
-		Error:     err,
-		Operation: "stun",
-	}.MaybeBuild()
+	if err != nil {
+		return netxlite.NewTopLevelGenericErrWrapper(err)
+	}
+	return nil
 }
 
+// errStunMissingInput means that the user did not provide any input
+var errStunMissingInput = errors.New("stun: missing input")
+
+// errStunMissingPortInURL means the URL is missing the port
+var errStunMissingPortInURL = errors.New("stun: missing port in URL")
+
+// errUnsupportedURLScheme means we don't support the URL scheme
+var errUnsupportedURLScheme = errors.New("stun: unsupported URL scheme")
+
 // Run implements ExperimentMeasurer.Run.
 func (m *Measurer) Run(
 	ctx context.Context, sess model.ExperimentSession,
@@ -72,10 +82,24 @@ func (m *Measurer) Run(
 	tk := new(TestKeys)
 	measurement.TestKeys = tk
 	registerExtensions(measurement)
-	if err := wrap(tk.run(ctx, m.config, sess, measurement, callbacks)); err != nil {
+	input := string(measurement.Input)
+	if input == "" {
+		return errStunMissingInput
+	}
+	URL, err := url.Parse(input)
+	if err != nil {
+		return err
+	}
+	if URL.Port() == "" {
+		return errStunMissingPortInURL
+	}
+	if URL.Scheme != "stun" {
+		return errUnsupportedURLScheme
+	}
+	if err := wrap(tk.run(ctx, m.config, sess, measurement, callbacks, URL.Host)); err != nil {
 		s := err.Error()
 		tk.Failure = &s
-		return err
+		return nil // we want to submit this measurement
 	}
 	return nil
 }
@@ -83,12 +107,8 @@ func (m *Measurer) Run(
 func (tk *TestKeys) run(
 	ctx context.Context, config Config, sess model.ExperimentSession,
 	measurement *model.Measurement, callbacks model.ExperimentCallbacks,
+	endpoint string,
 ) error {
-	const defaultAddress = "stun.l.google.com:19302"
-	endpoint := string(measurement.Input)
-	if endpoint == "" {
-		endpoint = defaultAddress
-	}
 	callbacks.OnProgress(0, fmt.Sprintf("stunreachability: measuring: %s...", endpoint))
 	defer callbacks.OnProgress(
 		1, fmt.Sprintf("stunreachability: measuring: %s... done", endpoint))
@@ -113,7 +133,7 @@ func (tk *TestKeys) run(
 }
 
 func (tk *TestKeys) do(
-	ctx context.Context, config Config, dialer dialer.Dialer, endpoint string) error {
+	ctx context.Context, config Config, dialer model.Dialer, endpoint string) error {
 	dialContext := dialer.DialContext
 	if config.dialContext != nil {
 		dialContext = config.dialContext
