@@ -16,10 +16,10 @@ import (
 	"time"
 
 	"github.com/ooni/probe-cli/v3/internal/engine/experiment/tlstool/internal"
-	"github.com/ooni/probe-cli/v3/internal/engine/model"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx/archival"
-	"github.com/ooni/probe-cli/v3/internal/engine/runtimex"
+	"github.com/ooni/probe-cli/v3/internal/model"
+	"github.com/ooni/probe-cli/v3/internal/runtimex"
 )
 
 const (
@@ -104,10 +104,10 @@ func (m Measurer) Run(
 			Failure: archival.NewFailure(err),
 		}
 	}
-	return nil
+	return nil // return nil so we always submit the measurement
 }
 
-func (m Measurer) newDialer(logger model.Logger) netx.Dialer {
+func (m Measurer) newDialer(logger model.Logger) model.Dialer {
 	// TODO(bassosimone): this is a resolver that should hopefully work
 	// in many places. Maybe allow to configure it?
 	resolver, err := netx.NewDNSClientWithOverrides(netx.Config{Logger: logger},
