@@ -9,8 +9,8 @@ import (
 
 	"github.com/apex/log"
 	"github.com/ooni/probe-cli/v3/internal/engine/experiment/urlgetter"
-	"github.com/ooni/probe-cli/v3/internal/engine/internal/mockable"
-	"github.com/ooni/probe-cli/v3/internal/engine/netx/errorx"
+	"github.com/ooni/probe-cli/v3/internal/engine/mockable"
+	"github.com/ooni/probe-cli/v3/internal/netxlite"
 )
 
 func TestGetterWithVeryShortTimeout(t *testing.T) {
@@ -31,7 +31,7 @@ func TestGetterWithVeryShortTimeout(t *testing.T) {
 	if tk.BootstrapTime != 0 {
 		t.Fatal("not the BootstrapTime we expected")
 	}
-	if tk.FailedOperation == nil || *tk.FailedOperation != errorx.TopLevelOperation {
+	if tk.FailedOperation == nil || *tk.FailedOperation != netxlite.TopLevelOperation {
 		t.Fatal("not the FailedOperation we expected")
 	}
 	if tk.Failure == nil || *tk.Failure != "generic_timeout_error" {
@@ -98,7 +98,7 @@ func TestGetterWithCancelledContextVanilla(t *testing.T) {
 	if tk.BootstrapTime != 0 {
 		t.Fatal("not the BootstrapTime we expected")
 	}
-	if tk.FailedOperation == nil || *tk.FailedOperation != errorx.TopLevelOperation {
+	if tk.FailedOperation == nil || *tk.FailedOperation != netxlite.TopLevelOperation {
 		t.Fatal("not the FailedOperation we expected")
 	}
 	if tk.Failure == nil || !strings.HasSuffix(*tk.Failure, "interrupted") {
@@ -166,7 +166,7 @@ func TestGetterWithCancelledContextAndMethod(t *testing.T) {
 	if tk.BootstrapTime != 0 {
 		t.Fatal("not the BootstrapTime we expected")
 	}
-	if tk.FailedOperation == nil || *tk.FailedOperation != errorx.TopLevelOperation {
+	if tk.FailedOperation == nil || *tk.FailedOperation != netxlite.TopLevelOperation {
 		t.Fatal("not the FailedOperation we expected")
 	}
 	if tk.Failure == nil || !strings.HasSuffix(*tk.Failure, "interrupted") {
@@ -236,7 +236,7 @@ func TestGetterWithCancelledContextNoFollowRedirects(t *testing.T) {
 	if tk.BootstrapTime != 0 {
 		t.Fatal("not the BootstrapTime we expected")
 	}
-	if tk.FailedOperation == nil || *tk.FailedOperation != errorx.TopLevelOperation {
+	if tk.FailedOperation == nil || *tk.FailedOperation != netxlite.TopLevelOperation {
 		t.Fatal("not the FailedOperation we expected")
 	}
 	if tk.Failure == nil || !strings.HasSuffix(*tk.Failure, "interrupted") {
@@ -306,7 +306,7 @@ func TestGetterWithCancelledContextCannotStartTunnel(t *testing.T) {
 	if tk.BootstrapTime != 0 {
 		t.Fatal("not the BootstrapTime we expected")
 	}
-	if tk.FailedOperation == nil || *tk.FailedOperation != errorx.TopLevelOperation {
+	if tk.FailedOperation == nil || *tk.FailedOperation != netxlite.TopLevelOperation {
 		t.Fatal("not the FailedOperation we expected")
 	}
 	if tk.Failure == nil || *tk.Failure != "interrupted" {
@@ -361,7 +361,7 @@ func TestGetterWithCancelledContextUnknownResolverURL(t *testing.T) {
 	if tk.BootstrapTime != 0 {
 		t.Fatal("not the BootstrapTime we expected")
 	}
-	if tk.FailedOperation == nil || *tk.FailedOperation != errorx.TopLevelOperation {
+	if tk.FailedOperation == nil || *tk.FailedOperation != netxlite.TopLevelOperation {
 		t.Fatal("not the FailedOperation we expected")
 	}
 	if tk.Failure == nil || *tk.Failure != "unknown_failure: unsupported resolver scheme" {
@@ -429,9 +429,6 @@ func TestGetterIntegrationHTTPS(t *testing.T) {
 		connect                  bool
 		tlsHandshakeStart        bool
 		tlsHandshakeDone         bool
-		httpWroteHeaders         bool
-		httpWroteRequest         bool
-		httpFirstResponseByte    bool
 		httpResponseMetadata     bool
 		httpResponseBodySnapshot bool
 		httpTransactionDone      bool
@@ -446,18 +443,12 @@ func TestGetterIntegrationHTTPS(t *testing.T) {
 			resolveStart = true
 		case "resolve_done":
 			resolveDone = true
-		case errorx.ConnectOperation:
+		case netxlite.ConnectOperation:
 			connect = true
 		case "tls_handshake_start":
 			tlsHandshakeStart = true
 		case "tls_handshake_done":
 			tlsHandshakeDone = true
-		case "http_wrote_headers":
-			httpWroteHeaders = true
-		case "http_wrote_request":
-			httpWroteRequest = true
-		case "http_first_response_byte":
-			httpFirstResponseByte = true
 		case "http_response_metadata":
 			httpResponseMetadata = true
 		case "http_response_body_snapshot":
@@ -474,9 +465,6 @@ func TestGetterIntegrationHTTPS(t *testing.T) {
 	ok = ok && connect
 	ok = ok && tlsHandshakeStart
 	ok = ok && tlsHandshakeDone
-	ok = ok && httpWroteHeaders
-	ok = ok && httpWroteRequest
-	ok = ok && httpFirstResponseByte
 	ok = ok && httpResponseMetadata
 	ok = ok && httpResponseBodySnapshot
 	ok = ok && httpTransactionDone
@@ -570,9 +558,6 @@ func TestGetterIntegrationTLSHandshake(t *testing.T) {
 		connect                  bool
 		tlsHandshakeStart        bool
 		tlsHandshakeDone         bool
-		httpWroteHeaders         bool
-		httpWroteRequest         bool
-		httpFirstResponseByte    bool
 		httpResponseMetadata     bool
 		httpResponseBodySnapshot bool
 		httpTransactionDone      bool
@@ -587,18 +572,12 @@ func TestGetterIntegrationTLSHandshake(t *testing.T) {
 			resolveStart = true
 		case "resolve_done":
 			resolveDone = true
-		case errorx.ConnectOperation:
+		case netxlite.ConnectOperation:
 			connect = true
 		case "tls_handshake_start":
 			tlsHandshakeStart = true
 		case "tls_handshake_done":
 			tlsHandshakeDone = true
-		case "http_wrote_headers":
-			httpWroteHeaders = true
-		case "http_wrote_request":
-			httpWroteRequest = true
-		case "http_first_response_byte":
-			httpFirstResponseByte = true
 		case "http_response_metadata":
 			httpResponseMetadata = true
 		case "http_response_body_snapshot":
@@ -615,9 +594,6 @@ func TestGetterIntegrationTLSHandshake(t *testing.T) {
 	ok = ok && connect
 	ok = ok && tlsHandshakeStart
 	ok = ok && tlsHandshakeDone
-	ok = ok && !httpWroteHeaders
-	ok = ok && !httpWroteRequest
-	ok = ok && !httpFirstResponseByte
 	ok = ok && !httpResponseMetadata
 	ok = ok && !httpResponseBodySnapshot
 	ok = ok && !httpTransactionDone
@@ -688,9 +664,6 @@ func TestGetterHTTPSWithTunnel(t *testing.T) {
 		connect                  bool
 		tlsHandshakeStart        bool
 		tlsHandshakeDone         bool
-		httpWroteHeaders         bool
-		httpWroteRequest         bool
-		httpFirstResponseByte    bool
 		httpResponseMetadata     bool
 		httpResponseBodySnapshot bool
 		httpTransactionDone      bool
@@ -705,18 +678,12 @@ func TestGetterHTTPSWithTunnel(t *testing.T) {
 			resolveStart = true
 		case "resolve_done":
 			resolveDone = true
-		case errorx.ConnectOperation:
+		case netxlite.ConnectOperation:
 			connect = true
 		case "tls_handshake_start":
 			tlsHandshakeStart = true
 		case "tls_handshake_done":
 			tlsHandshakeDone = true
-		case "http_wrote_headers":
-			httpWroteHeaders = true
-		case "http_wrote_request":
-			httpWroteRequest = true
-		case "http_first_response_byte":
-			httpFirstResponseByte = true
 		case "http_response_metadata":
 			httpResponseMetadata = true
 		case "http_response_body_snapshot":
@@ -733,9 +700,6 @@ func TestGetterHTTPSWithTunnel(t *testing.T) {
 	ok = ok && connect
 	ok = ok && tlsHandshakeStart
 	ok = ok && tlsHandshakeDone
-	ok = ok && httpWroteHeaders
-	ok = ok && httpWroteRequest
-	ok = ok && httpFirstResponseByte
 	ok = ok && httpResponseMetadata
 	ok = ok && httpResponseBodySnapshot
 	ok = ok && httpTransactionDone
