@@ -4,9 +4,9 @@ import (
 	"context"
 
 	"github.com/ooni/probe-cli/v3/internal/engine/geolocate"
-	"github.com/ooni/probe-cli/v3/internal/engine/httpx"
-	"github.com/ooni/probe-cli/v3/internal/engine/model"
-	"github.com/ooni/probe-cli/v3/internal/engine/netx/errorx"
+	"github.com/ooni/probe-cli/v3/internal/httpx"
+	"github.com/ooni/probe-cli/v3/internal/model"
+	"github.com/ooni/probe-cli/v3/internal/netxlite"
 )
 
 // ControlRequest is the request that we send to the control
@@ -52,17 +52,18 @@ type ControlResponse struct {
 func Control(
 	ctx context.Context, sess model.ExperimentSession,
 	thAddr string, creq ControlRequest) (out ControlResponse, err error) {
-	clnt := httpx.Client{
+	clnt := &httpx.APIClientTemplate{
 		BaseURL:    thAddr,
 		HTTPClient: sess.DefaultHTTPClient(),
 		Logger:     sess.Logger(),
+		UserAgent:  sess.UserAgent(),
 	}
 	sess.Logger().Infof("control for %s...", creq.HTTPRequest)
 	// make sure error is wrapped
-	err = errorx.SafeErrWrapperBuilder{
-		Error:     clnt.PostJSON(ctx, "/", creq, &out),
-		Operation: errorx.TopLevelOperation,
-	}.MaybeBuild()
+	err = clnt.WithBodyLogging().Build().PostJSON(ctx, "/", creq, &out)
+	if err != nil {
+		err = netxlite.NewTopLevelGenericErrWrapper(err)
+	}
 	sess.Logger().Infof("control for %s... %+v", creq.HTTPRequest, err)
 	(&out.DNS).FillASNs(sess)
 	return
