@@ -13,7 +13,7 @@ import (
 	"testing"
 
 	"github.com/ooni/probe-cli/v3/internal/engine/experiment/example"
-	"github.com/ooni/probe-cli/v3/internal/engine/model"
+	"github.com/ooni/probe-cli/v3/internal/model"
 )
 
 func TestCreateAll(t *testing.T) {
@@ -213,8 +213,8 @@ func TestMeasurementFailure(t *testing.T) {
 	if err.Error() != "mocked error" {
 		t.Fatal("unexpected error type")
 	}
-	if measurement == nil {
-		t.Fatal("expected non nil measurement here")
+	if measurement != nil {
+		t.Fatal("expected nil measurement here")
 	}
 }
 
@@ -454,7 +454,7 @@ func TestOpenReportFailure(t *testing.T) {
 		t.Fatal(err)
 	}
 	exp := builder.NewExperiment()
-	exp.session.selectedProbeService = &model.Service{
+	exp.session.selectedProbeService = &model.OOAPIService{
 		Address: server.URL,
 		Type:    "https",
 	}
@@ -475,7 +475,7 @@ func TestOpenReportNewClientFailure(t *testing.T) {
 		t.Fatal(err)
 	}
 	exp := builder.NewExperiment()
-	exp.session.selectedProbeService = &model.Service{
+	exp.session.selectedProbeService = &model.OOAPIService{
 		Address: "antani:///",
 		Type:    "antani",
 	}
@@ -523,7 +523,7 @@ func TestOpenReportNonHTTPS(t *testing.T) {
 	}
 	sess := newSessionForTestingNoLookups(t)
 	defer sess.Close()
-	sess.availableProbeServices = []model.Service{
+	sess.availableProbeServices = []model.OOAPIService{
 		{
 			Address: "antani",
 			Type:    "mascetti",
