@@ -3,7 +3,7 @@ package engine
 import (
 	"os"
 
-	"github.com/ooni/probe-cli/v3/internal/engine/model"
+	"github.com/ooni/probe-cli/v3/internal/model"
 )
 
 func (e *Experiment) SaveMeasurementEx(
