@@ -8,7 +8,7 @@ import (
 	"strconv"
 
 	"github.com/iancoleman/strcase"
-	"github.com/ooni/probe-cli/v3/internal/engine/model"
+	"github.com/ooni/probe-cli/v3/internal/model"
 )
 
 // InputPolicy describes the experiment policy with respect to input. That is
@@ -36,6 +36,11 @@ const (
 	// InputNone indicates that the experiment does not want any
 	// input and ignores the input if provided with it.
 	InputNone = InputPolicy("none")
+
+	// We gather input from StaticInput and SourceFiles. If there is
+	// input, we return it. Otherwise, we return an internal static
+	// list of inputs to be used with this experiment.
+	InputOrStaticDefault = InputPolicy("or_static_default")
 )
 
 // ExperimentBuilder is an experiment builder.
@@ -183,10 +188,18 @@ func (b *ExperimentBuilder) NewExperiment() *Experiment {
 
 // canonicalizeExperimentName allows code to provide experiment names
 // in a more flexible way, where we have aliases.
+//
+// Because we allow for uppercase experiment names for backwards
+// compatibility with MK, we need to add some exceptions here when
+// mapping (e.g., DNSCheck => dnscheck).
 func canonicalizeExperimentName(name string) string {
 	switch name = strcase.ToSnake(name); name {
 	case "ndt_7":
 		name = "ndt" // since 2020-03-18, we use ndt7 to implement ndt by default
+	case "dns_check":
+		name = "dnscheck"
+	case "stun_reachability":
+		name = "stunreachability"
 	default:
 	}
 	return name
