@@ -4,7 +4,6 @@ import (
 	"context"
 	"net"
 	"net/http"
-	"os"
 	"testing"
 
 	"github.com/apex/log"
@@ -12,11 +11,6 @@ import (
 )
 
 func TestIPLookupWorksUsingIPConfig(t *testing.T) {
-	if os.Getenv("CI") == "true" {
-		// See https://github.com/ooni/probe-cli/pull/259/checks?check_run_id=2166066881#step:5:123
-		// as well as https://github.com/ooni/probe/issues/1418.
-		t.Skip("This test does not work with GitHub Actions")
-	}
 	ip, err := ipConfigIPLookup(
 		context.Background(),
 		http.DefaultClient,
