@@ -5,7 +5,8 @@ import (
 	"net/http"
 
 	"github.com/ooni/probe-cli/v3/internal/engine/httpheader"
-	"github.com/ooni/probe-cli/v3/internal/engine/httpx"
+	"github.com/ooni/probe-cli/v3/internal/httpx"
+	"github.com/ooni/probe-cli/v3/internal/model"
 )
 
 type ipInfoResponse struct {
@@ -15,17 +16,17 @@ type ipInfoResponse struct {
 func ipInfoIPLookup(
 	ctx context.Context,
 	httpClient *http.Client,
-	logger Logger,
+	logger model.Logger,
 	userAgent string,
 ) (string, error) {
 	var v ipInfoResponse
-	err := (httpx.Client{
+	err := (&httpx.APIClientTemplate{
 		Accept:     "application/json",
 		BaseURL:    "https://ipinfo.io",
 		HTTPClient: httpClient,
 		Logger:     logger,
 		UserAgent:  httpheader.CLIUserAgent(), // we must be a CLI client
-	}).GetJSON(ctx, "/", &v)
+	}).WithBodyLogging().Build().GetJSON(ctx, "/", &v)
 	if err != nil {
 		return DefaultProbeIP, err
 	}
