@@ -9,8 +9,9 @@ import (
 	"net/http"
 	"time"
 
-	"github.com/ooni/probe-cli/v3/internal/engine/internal/multierror"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx"
+	"github.com/ooni/probe-cli/v3/internal/model"
+	"github.com/ooni/probe-cli/v3/internal/multierror"
 )
 
 var (
@@ -25,7 +26,7 @@ var (
 
 type lookupFunc func(
 	ctx context.Context, client *http.Client,
-	logger Logger, userAgent string,
+	logger model.Logger, userAgent string,
 ) (string, error)
 
 type method struct {
@@ -39,6 +40,10 @@ var (
 			name: "avast",
 			fn:   avastIPLookup,
 		},
+		{
+			name: "cloudflare",
+			fn:   cloudflareIPLookup,
+		},
 		{
 			name: "ipconfig",
 			fn:   ipConfigIPLookup,
@@ -64,10 +69,10 @@ var (
 
 type ipLookupClient struct {
 	// Resolver is the resolver to use for HTTP.
-	Resolver Resolver
+	Resolver model.Resolver
 
 	// Logger is the logger to use
-	Logger Logger
+	Logger model.Logger
 
 	// UserAgent is the user agent to use
 	UserAgent string
@@ -86,6 +91,10 @@ func makeSlice() []method {
 func (c ipLookupClient) doWithCustomFunc(
 	ctx context.Context, fn lookupFunc,
 ) (string, error) {
+	// Reliability fix: let these mechanisms timeout earlier.
+	const timeout = 7 * time.Second
+	ctx, cancel := context.WithTimeout(ctx, timeout)
+	defer cancel()
 	// Implementation note: we MUST use an HTTP client that we're
 	// sure IS NOT using any proxy. To this end, we construct a
 	// client ourself that we know is not proxied.
