@@ -2,5 +2,5 @@ package httpheader
 
 // AcceptLanguage returns the Accept-Language header used for measuring.
 func AcceptLanguage() string {
-	return "en-US;q=0.8,en;q=0.5"
+	return "en-US,en;q=0.9"
 }
