@@ -6,10 +6,12 @@ import (
 	"errors"
 	"fmt"
 	"io/fs"
+	"net/url"
 
 	"github.com/apex/log"
-	"github.com/ooni/probe-cli/v3/internal/engine/internal/fsx"
-	"github.com/ooni/probe-cli/v3/internal/engine/model"
+	"github.com/ooni/probe-cli/v3/internal/fsx"
+	"github.com/ooni/probe-cli/v3/internal/model"
+	"github.com/ooni/probe-cli/v3/internal/stuninput"
 )
 
 // These errors are returned by the InputLoader.
@@ -18,13 +20,14 @@ var (
 	ErrDetectedEmptyFile = errors.New("file did not contain any input")
 	ErrInputRequired     = errors.New("no input provided")
 	ErrNoInputExpected   = errors.New("we did not expect any input")
+	ErrNoStaticInput     = errors.New("no static input for this experiment")
 )
 
 // InputLoaderSession is the session according to an InputLoader. We
 // introduce this abstraction because it helps us with testing.
 type InputLoaderSession interface {
 	CheckIn(ctx context.Context,
-		config *model.CheckInConfig) (*model.CheckInInfo, error)
+		config *model.OOAPICheckInConfig) (*model.OOAPICheckInInfo, error)
 }
 
 // InputLoaderLogger is the logger according to an InputLoader.
@@ -58,6 +61,12 @@ type InputLoaderLogger interface {
 // input, we return it. Otherwise, we use OONI's probe services
 // to gather input using the best API for the task.
 //
+// InputOrStaticDefault
+//
+// We gather input from StaticInput and SourceFiles. If there is
+// input, we return it. Otherwise, we return an internal static
+// list of inputs to be used with this experiment.
+//
 // InputStrictlyRequired
 //
 // We gather input from StaticInput and SourceFiles. If there is
@@ -67,7 +76,11 @@ type InputLoader struct {
 	// not set, then we'll create a default config. If set but
 	// there are fields inside it that are not set, then we
 	// will set them to a default value.
-	CheckInConfig *model.CheckInConfig
+	CheckInConfig *model.OOAPICheckInConfig
+
+	// ExperimentName is the name of the experiment. This field
+	// is only used together with the InputOrStaticDefault policy.
+	ExperimentName string
 
 	// InputPolicy specifies the input policy for the
 	// current experiment. We will not load any input if
@@ -97,7 +110,7 @@ type InputLoader struct {
 
 // Load attempts to load input using the specified input loader. We will
 // return a list of URLs because this is the only input we support.
-func (il *InputLoader) Load(ctx context.Context) ([]model.URLInfo, error) {
+func (il *InputLoader) Load(ctx context.Context) ([]model.OOAPIURLInfo, error) {
 	switch il.InputPolicy {
 	case InputOptional:
 		return il.loadOptional()
@@ -105,32 +118,34 @@ func (il *InputLoader) Load(ctx context.Context) ([]model.URLInfo, error) {
 		return il.loadOrQueryBackend(ctx)
 	case InputStrictlyRequired:
 		return il.loadStrictlyRequired(ctx)
+	case InputOrStaticDefault:
+		return il.loadOrStaticDefault(ctx)
 	default:
 		return il.loadNone()
 	}
 }
 
 // loadNone implements the InputNone policy.
-func (il *InputLoader) loadNone() ([]model.URLInfo, error) {
+func (il *InputLoader) loadNone() ([]model.OOAPIURLInfo, error) {
 	if len(il.StaticInputs) > 0 || len(il.SourceFiles) > 0 {
 		return nil, ErrNoInputExpected
 	}
 	// Note that we need to return a single empty entry.
-	return []model.URLInfo{{}}, nil
+	return []model.OOAPIURLInfo{{}}, nil
 }
 
 // loadOptional implements the InputOptional policy.
-func (il *InputLoader) loadOptional() ([]model.URLInfo, error) {
+func (il *InputLoader) loadOptional() ([]model.OOAPIURLInfo, error) {
 	inputs, err := il.loadLocal()
 	if err == nil && len(inputs) <= 0 {
 		// Note that we need to return a single empty entry.
-		inputs = []model.URLInfo{{}}
+		inputs = []model.OOAPIURLInfo{{}}
 	}
 	return inputs, err
 }
 
 // loadStrictlyRequired implements the InputStrictlyRequired policy.
-func (il *InputLoader) loadStrictlyRequired(ctx context.Context) ([]model.URLInfo, error) {
+func (il *InputLoader) loadStrictlyRequired(ctx context.Context) ([]model.OOAPIURLInfo, error) {
 	inputs, err := il.loadLocal()
 	if err != nil || len(inputs) > 0 {
 		return inputs, err
@@ -139,7 +154,7 @@ func (il *InputLoader) loadStrictlyRequired(ctx context.Context) ([]model.URLInf
 }
 
 // loadOrQueryBackend implements the InputOrQueryBackend policy.
-func (il *InputLoader) loadOrQueryBackend(ctx context.Context) ([]model.URLInfo, error) {
+func (il *InputLoader) loadOrQueryBackend(ctx context.Context) ([]model.OOAPIURLInfo, error) {
 	inputs, err := il.loadLocal()
 	if err != nil || len(inputs) > 0 {
 		return inputs, err
@@ -147,14 +162,67 @@ func (il *InputLoader) loadOrQueryBackend(ctx context.Context) ([]model.URLInfo,
 	return il.loadRemote(ctx)
 }
 
+// TODO(https://github.com/ooni/probe/issues/1390): we need to
+// implement serving DNSCheck targets from the API
+var dnsCheckDefaultInput = []string{
+	"https://dns.google/dns-query",
+	"https://8.8.8.8/dns-query",
+	"dot://8.8.8.8:853/",
+	"dot://8.8.4.4:853/",
+	"https://8.8.4.4/dns-query",
+	"https://cloudflare-dns.com/dns-query",
+	"https://1.1.1.1/dns-query",
+	"https://1.0.0.1/dns-query",
+	"dot://1.1.1.1:853/",
+	"dot://1.0.0.1:853/",
+	"https://dns.quad9.net/dns-query",
+	"https://9.9.9.9/dns-query",
+	"dot://9.9.9.9:853/",
+	"dot://dns.quad9.net/",
+}
+
+var stunReachabilityDefaultInput = stuninput.AsnStunReachabilityInput()
+
+// StaticBareInputForExperiment returns the list of strings an
+// experiment should use as static input. In case there is no
+// static input for this experiment, we return an error.
+func StaticBareInputForExperiment(name string) ([]string, error) {
+	// Implementation note: we may be called from pkg/oonimkall
+	// with a non-canonical experiment name, so we need to convert
+	// the experiment name to be canonical before proceeding.
+	switch canonicalizeExperimentName(name) {
+	case "dnscheck":
+		return dnsCheckDefaultInput, nil
+	case "stunreachability":
+		return stunReachabilityDefaultInput, nil
+	default:
+		return nil, ErrNoStaticInput
+	}
+}
+
+// staticInputForExperiment returns the static input for the given experiment
+// or an error if there's no static input for the experiment.
+func staticInputForExperiment(name string) ([]model.OOAPIURLInfo, error) {
+	return stringListToModelURLInfo(StaticBareInputForExperiment(name))
+}
+
+// loadOrStaticDefault implements the InputOrStaticDefault policy.
+func (il *InputLoader) loadOrStaticDefault(ctx context.Context) ([]model.OOAPIURLInfo, error) {
+	inputs, err := il.loadLocal()
+	if err != nil || len(inputs) > 0 {
+		return inputs, err
+	}
+	return staticInputForExperiment(il.ExperimentName)
+}
+
 // loadLocal loads inputs from StaticInputs and SourceFiles.
-func (il *InputLoader) loadLocal() ([]model.URLInfo, error) {
-	inputs := []model.URLInfo{}
+func (il *InputLoader) loadLocal() ([]model.OOAPIURLInfo, error) {
+	inputs := []model.OOAPIURLInfo{}
 	for _, input := range il.StaticInputs {
-		inputs = append(inputs, model.URLInfo{URL: input})
+		inputs = append(inputs, model.OOAPIURLInfo{URL: input})
 	}
 	for _, filepath := range il.SourceFiles {
-		extra, err := il.readfile(filepath, fsx.Open)
+		extra, err := il.readfile(filepath, fsx.OpenFile)
 		if err != nil {
 			return nil, err
 		}
@@ -172,8 +240,8 @@ type inputLoaderOpenFn func(filepath string) (fs.File, error)
 
 // readfile reads inputs from the specified file. The open argument should be
 // compatible with stdlib's fs.Open and helps us with unit testing.
-func (il *InputLoader) readfile(filepath string, open inputLoaderOpenFn) ([]model.URLInfo, error) {
-	inputs := []model.URLInfo{}
+func (il *InputLoader) readfile(filepath string, open inputLoaderOpenFn) ([]model.OOAPIURLInfo, error) {
+	inputs := []model.OOAPIURLInfo{}
 	filep, err := open(filepath)
 	if err != nil {
 		return nil, err
@@ -186,7 +254,7 @@ func (il *InputLoader) readfile(filepath string, open inputLoaderOpenFn) ([]mode
 	for scanner.Scan() {
 		line := scanner.Text()
 		if line != "" {
-			inputs = append(inputs, model.URLInfo{URL: line})
+			inputs = append(inputs, model.OOAPIURLInfo{URL: line})
 		}
 	}
 	if scanner.Err() != nil {
@@ -196,14 +264,14 @@ func (il *InputLoader) readfile(filepath string, open inputLoaderOpenFn) ([]mode
 }
 
 // loadRemote loads inputs from a remote source.
-func (il *InputLoader) loadRemote(ctx context.Context) ([]model.URLInfo, error) {
+func (il *InputLoader) loadRemote(ctx context.Context) ([]model.OOAPIURLInfo, error) {
 	config := il.CheckInConfig
 	if config == nil {
 		// Note: Session.CheckIn documentation says it will fill in
 		// any field with a required value with a reasonable default
 		// if such value is missing. So, here we just need to be
 		// concerned about NOT passing it a NULL pointer.
-		config = &model.CheckInConfig{}
+		config = &model.OOAPICheckInConfig{}
 	}
 	reply, err := il.checkIn(ctx, config)
 	if err != nil {
@@ -219,7 +287,7 @@ func (il *InputLoader) loadRemote(ctx context.Context) ([]model.URLInfo, error)
 // the URLs that are not part of the requested categories. This is done for
 // robustness, just in case we or the API do something wrong.
 func (il *InputLoader) checkIn(
-	ctx context.Context, config *model.CheckInConfig) (*model.CheckInInfo, error) {
+	ctx context.Context, config *model.OOAPICheckInConfig) (*model.OOAPICheckInInfo, error) {
 	reply, err := il.Session.CheckIn(ctx, config)
 	if err != nil {
 		return nil, err
@@ -236,7 +304,7 @@ func (il *InputLoader) checkIn(
 // preventMistakes makes the code more robust with respect to any possible
 // integration issue where the backend returns to us URLs that don't
 // belong to the category codes we requested.
-func (il *InputLoader) preventMistakes(input []model.URLInfo, categories []string) (output []model.URLInfo) {
+func (il *InputLoader) preventMistakes(input []model.OOAPIURLInfo, categories []string) (output []model.OOAPIURLInfo) {
 	if len(categories) <= 0 {
 		return input
 	}
@@ -264,3 +332,26 @@ func (il *InputLoader) logger() InputLoaderLogger {
 	}
 	return log.Log
 }
+
+// stringListToModelURLInfo is an utility function to convert
+// a list of strings containing URLs into a list of model.URLInfo
+// which would have been returned by an hypothetical backend
+// API serving input for a test for which we don't have an API
+// yet (e.g., stunreachability and dnscheck).
+func stringListToModelURLInfo(input []string, err error) ([]model.OOAPIURLInfo, error) {
+	if err != nil {
+		return nil, err
+	}
+	var output []model.OOAPIURLInfo
+	for _, URL := range input {
+		if _, err := url.Parse(URL); err != nil {
+			return nil, err
+		}
+		output = append(output, model.OOAPIURLInfo{
+			CategoryCode: "MISC", // hard to find a category
+			CountryCode:  "XX",   // representing no country
+			URL:          URL,
+		})
+	}
+	return output, nil
+}
