@@ -2,24 +2,23 @@ package engine
 
 import (
 	"context"
-	"sync/atomic"
 	"time"
 
-	"github.com/ooni/probe-cli/v3/internal/engine/model"
+	"github.com/ooni/probe-cli/v3/internal/model"
 )
 
 // InputProcessorExperiment is the Experiment
 // according to InputProcessor.
 type InputProcessorExperiment interface {
-	MeasureWithContext(
-		ctx context.Context, input string) (*model.Measurement, error)
+	MeasureAsync(
+		ctx context.Context, input string) (<-chan *model.Measurement, error)
 }
 
 // InputProcessorExperimentWrapper is a wrapper for an
 // Experiment that also allow to pass around the input index.
 type InputProcessorExperimentWrapper interface {
-	MeasureWithContext(
-		ctx context.Context, idx int, input string) (*model.Measurement, error)
+	MeasureAsync(
+		ctx context.Context, input string, idx int) (<-chan *model.Measurement, error)
 }
 
 // NewInputProcessorExperimentWrapper creates a new
@@ -33,9 +32,9 @@ type inputProcessorExperimentWrapper struct {
 	exp InputProcessorExperiment
 }
 
-func (ipew inputProcessorExperimentWrapper) MeasureWithContext(
-	ctx context.Context, idx int, input string) (*model.Measurement, error) {
-	return ipew.exp.MeasureWithContext(ctx, input)
+func (ipew inputProcessorExperimentWrapper) MeasureAsync(
+	ctx context.Context, input string, idx int) (<-chan *model.Measurement, error) {
+	return ipew.exp.MeasureAsync(ctx, input)
 }
 
 var _ InputProcessorExperimentWrapper = inputProcessorExperimentWrapper{}
@@ -50,7 +49,7 @@ type InputProcessor struct {
 	Experiment InputProcessorExperimentWrapper
 
 	// Inputs is the list of inputs to measure.
-	Inputs []model.URLInfo
+	Inputs []model.OOAPIURLInfo
 
 	// MaxRuntime is the optional maximum runtime
 	// when looping over a list of inputs (e.g. when
@@ -68,11 +67,6 @@ type InputProcessor struct {
 	// Submitter is the code that will submit measurements
 	// to the OONI collector.
 	Submitter InputProcessorSubmitterWrapper
-
-	// terminatedByMaxRuntime is an internal atomic variabile
-	// incremented when we're terminated by MaxRuntime. We
-	// only use this variable when testing.
-	terminatedByMaxRuntime int32
 }
 
 // InputProcessorSaverWrapper is InputProcessor's
@@ -129,29 +123,49 @@ func (ipsw inputProcessorSubmitterWrapper) Submit(
 // though is free to choose different policies by configuring
 // the Experiment, Submitter, and Saver fields properly.
 func (ip *InputProcessor) Run(ctx context.Context) error {
+	_, err := ip.run(ctx)
+	return err
+}
+
+// These are the reasons why run could stop.
+const (
+	stopNormal = (1 << iota)
+	stopMaxRuntime
+)
+
+// run is like Run but, in addition to returning an error, it
+// also returns the reason why we stopped.
+func (ip *InputProcessor) run(ctx context.Context) (int, error) {
 	start := time.Now()
 	for idx, url := range ip.Inputs {
 		if ip.MaxRuntime > 0 && time.Since(start) > ip.MaxRuntime {
-			atomic.AddInt32(&ip.terminatedByMaxRuntime, 1)
-			return nil
+			return stopMaxRuntime, nil
 		}
 		input := url.URL
-		meas, err := ip.Experiment.MeasureWithContext(ctx, idx, input)
+		var measurements []*model.Measurement
+		source, err := ip.Experiment.MeasureAsync(ctx, input, idx)
 		if err != nil {
-			return err
+			return 0, err
 		}
-		meas.AddAnnotations(ip.Annotations)
-		meas.Options = ip.Options
-		err = ip.Submitter.Submit(ctx, idx, meas)
-		if err != nil {
-			return err
+		// NOTE: we don't want to intermix measuring with submitting
+		// therefore we collect all measurements first
+		for meas := range source {
+			measurements = append(measurements, meas)
 		}
-		// Note: must be after submission because submission modifies
-		// the measurement to include the report ID.
-		err = ip.Saver.SaveMeasurement(idx, meas)
-		if err != nil {
-			return err
+		for _, meas := range measurements {
+			meas.AddAnnotations(ip.Annotations)
+			meas.Options = ip.Options
+			err = ip.Submitter.Submit(ctx, idx, meas)
+			if err != nil {
+				return 0, err
+			}
+			// Note: must be after submission because submission modifies
+			// the measurement to include the report ID.
+			err = ip.Saver.SaveMeasurement(idx, meas)
+			if err != nil {
+				return 0, err
+			}
 		}
 	}
-	return nil
+	return stopNormal, nil
 }
