@@ -33,9 +33,10 @@ import (
 	"sync"
 	"time"
 
-	"github.com/ooni/probe-cli/v3/internal/engine/internal/multierror"
-	"github.com/ooni/probe-cli/v3/internal/engine/netx/bytecounter"
-	"github.com/ooni/probe-cli/v3/internal/engine/runtimex"
+	"github.com/ooni/probe-cli/v3/internal/bytecounter"
+	"github.com/ooni/probe-cli/v3/internal/model"
+	"github.com/ooni/probe-cli/v3/internal/multierror"
+	"github.com/ooni/probe-cli/v3/internal/runtimex"
 )
 
 // Resolver is the session resolver. Resolver will try to use
@@ -45,6 +46,9 @@ import (
 // and therefore we can generally give preference to underlying
 // DoT/DoH resolvers that work better.
 //
+// Make sure you fill the mandatory fields (indicated below)
+// before using this data structure.
+//
 // You MUST NOT modify public fields of this structure once it
 // has been created, because that MAY lead to data races.
 //
@@ -57,15 +61,14 @@ type Resolver struct {
 	// field is not set, then we won't count the bytes.
 	ByteCounter *bytecounter.Counter
 
-	// KVStore is the optional key-value store where you
+	// KVStore is the MANDATORY key-value store where you
 	// want us to write statistics about which resolver is
-	// working better in your network. If this field is
-	// not set, then we'll use a in-memory store.
-	KVStore KVStore
+	// working better in your network.
+	KVStore model.KeyValueStore
 
 	// Logger is the optional logger you want us to use
 	// to emit log messages.
-	Logger Logger
+	Logger model.Logger
 
 	// ProxyURL is the optional URL of the socks5 proxy
 	// we should be using. If not set, then we WON'T use
@@ -107,6 +110,11 @@ func (r *Resolver) Stats() string {
 	return fmt.Sprintf("sessionresolver: %s", string(data))
 }
 
+// LookupHTTPS implements Resolver.LookupHTTPS.
+func (r *Resolver) LookupHTTPS(ctx context.Context, domain string) (*model.HTTPSSvc, error) {
+	return nil, errors.New("not implemented")
+}
+
 // ErrLookupHost indicates that LookupHost failed.
 var ErrLookupHost = errors.New("sessionresolver: LookupHost failed")
 
