@@ -2,10 +2,11 @@ package netx
 
 import (
 	"context"
-	"io/ioutil"
 	"net"
 	"net/http"
 	"time"
+
+	"github.com/ooni/probe-cli/v3/internal/netxlite"
 )
 
 type FakeDialer struct {
@@ -18,6 +19,8 @@ func (d FakeDialer) DialContext(ctx context.Context, network, address string) (n
 	return d.Conn, d.Err
 }
 
+func (d FakeDialer) CloseIdleConnections() {}
+
 type FakeTransport struct {
 	Err  error
 	Func func(*http.Request) (*http.Response, error)
@@ -30,7 +33,7 @@ func (txp FakeTransport) RoundTrip(req *http.Request) (*http.Response, error) {
 		return txp.Func(req)
 	}
 	if req.Body != nil {
-		ioutil.ReadAll(req.Body)
+		netxlite.ReadAllContext(req.Context(), req.Body)
 		req.Body.Close()
 	}
 	if txp.Err != nil {
