@@ -2,63 +2,34 @@ package httptransport
 
 import (
 	"bytes"
-	"errors"
+	"context"
 	"io"
-	"io/ioutil"
 	"net/http"
-	"net/http/httptrace"
 	"time"
 
 	"github.com/ooni/probe-cli/v3/internal/engine/netx/trace"
+	"github.com/ooni/probe-cli/v3/internal/model"
+	"github.com/ooni/probe-cli/v3/internal/netxlite"
 )
 
-// SaverPerformanceHTTPTransport is a RoundTripper that saves
-// performance events occurring during the round trip
-type SaverPerformanceHTTPTransport struct {
-	RoundTripper
-	Saver *trace.Saver
-}
-
-// RoundTrip implements RoundTripper.RoundTrip
-func (txp SaverPerformanceHTTPTransport) RoundTrip(req *http.Request) (*http.Response, error) {
-	tracep := httptrace.ContextClientTrace(req.Context())
-	if tracep == nil {
-		tracep = &httptrace.ClientTrace{
-			WroteHeaders: func() {
-				txp.Saver.Write(trace.Event{Name: "http_wrote_headers", Time: time.Now()})
-			},
-			WroteRequest: func(httptrace.WroteRequestInfo) {
-				txp.Saver.Write(trace.Event{Name: "http_wrote_request", Time: time.Now()})
-			},
-			GotFirstResponseByte: func() {
-				txp.Saver.Write(trace.Event{
-					Name: "http_first_response_byte", Time: time.Now()})
-			},
-		}
-		req = req.WithContext(httptrace.WithClientTrace(req.Context(), tracep))
-	}
-	return txp.RoundTripper.RoundTrip(req)
-}
-
 // SaverMetadataHTTPTransport is a RoundTripper that saves
 // events related to HTTP request and response metadata
 type SaverMetadataHTTPTransport struct {
-	RoundTripper
-	Saver     *trace.Saver
-	Transport string
+	model.HTTPTransport
+	Saver *trace.Saver
 }
 
 // RoundTrip implements RoundTripper.RoundTrip
 func (txp SaverMetadataHTTPTransport) RoundTrip(req *http.Request) (*http.Response, error) {
 	txp.Saver.Write(trace.Event{
-		HTTPHeaders: req.Header,
+		HTTPHeaders: txp.CloneHeaders(req),
 		HTTPMethod:  req.Method,
 		HTTPURL:     req.URL.String(),
-		Transport:   txp.Transport,
+		Transport:   txp.HTTPTransport.Network(),
 		Name:        "http_request_metadata",
 		Time:        time.Now(),
 	})
-	resp, err := txp.RoundTripper.RoundTrip(req)
+	resp, err := txp.HTTPTransport.RoundTrip(req)
 	if err != nil {
 		return nil, err
 	}
@@ -71,10 +42,23 @@ func (txp SaverMetadataHTTPTransport) RoundTrip(req *http.Request) (*http.Respon
 	return resp, err
 }
 
+// CloneHeaders returns a clone of the headers where we have
+// also set the host header, which normally is not set by
+// golang until it serializes the request itself.
+func (txp SaverMetadataHTTPTransport) CloneHeaders(req *http.Request) http.Header {
+	header := req.Header.Clone()
+	if req.Host != "" {
+		header.Set("Host", req.Host)
+	} else {
+		header.Set("Host", req.URL.Host)
+	}
+	return header
+}
+
 // SaverTransactionHTTPTransport is a RoundTripper that saves
 // events related to the HTTP transaction
 type SaverTransactionHTTPTransport struct {
-	RoundTripper
+	model.HTTPTransport
 	Saver *trace.Saver
 }
 
@@ -84,7 +68,7 @@ func (txp SaverTransactionHTTPTransport) RoundTrip(req *http.Request) (*http.Res
 		Name: "http_transaction_start",
 		Time: time.Now(),
 	})
-	resp, err := txp.RoundTripper.RoundTrip(req)
+	resp, err := txp.HTTPTransport.RoundTrip(req)
 	txp.Saver.Write(trace.Event{
 		Err:  err,
 		Name: "http_transaction_done",
@@ -96,7 +80,7 @@ func (txp SaverTransactionHTTPTransport) RoundTrip(req *http.Request) (*http.Res
 // SaverBodyHTTPTransport is a RoundTripper that saves
 // body events occurring during the round trip
 type SaverBodyHTTPTransport struct {
-	RoundTripper
+	model.HTTPTransport
 	Saver        *trace.Saver
 	SnapshotSize int
 }
@@ -109,7 +93,7 @@ func (txp SaverBodyHTTPTransport) RoundTrip(req *http.Request) (*http.Response,
 		snapsize = txp.SnapshotSize
 	}
 	if req.Body != nil {
-		data, err := saverSnapRead(req.Body, snapsize)
+		data, err := saverSnapRead(req.Context(), req.Body, snapsize)
 		if err != nil {
 			return nil, err
 		}
@@ -121,12 +105,11 @@ func (txp SaverBodyHTTPTransport) RoundTrip(req *http.Request) (*http.Response,
 			Time:            time.Now(),
 		})
 	}
-	resp, err := txp.RoundTripper.RoundTrip(req)
+	resp, err := txp.HTTPTransport.RoundTrip(req)
 	if err != nil {
 		return nil, err
 	}
-	data, err := saverSnapRead(resp.Body, snapsize)
-	err = ignoreExpectedEOF(err, resp)
+	data, err := saverSnapRead(req.Context(), resp.Body, snapsize)
 	if err != nil {
 		resp.Body.Close()
 		return nil, err
@@ -141,24 +124,8 @@ func (txp SaverBodyHTTPTransport) RoundTrip(req *http.Request) (*http.Response,
 	return resp, nil
 }
 
-// ignoreExpectedEOF converts an error signalling the end of the body
-// into a success. We know that we are in such condition when the
-// resp.Close hint flag is set to true. (Thanks, stdlib!)
-//
-// See https://github.com/ooni/probe-engine/issues/1191 for an analysis
-// of how this error was impacting measurements and data quality.
-func ignoreExpectedEOF(err error, resp *http.Response) error {
-	if err == nil {
-		return nil
-	}
-	if errors.Is(err, io.EOF) && resp.Close {
-		return nil
-	}
-	return err
-}
-
-func saverSnapRead(r io.ReadCloser, snapsize int) ([]byte, error) {
-	return ioutil.ReadAll(io.LimitReader(r, int64(snapsize)))
+func saverSnapRead(ctx context.Context, r io.ReadCloser, snapsize int) ([]byte, error) {
+	return netxlite.ReadAllContext(ctx, io.LimitReader(r, int64(snapsize)))
 }
 
 func saverCompose(data []byte, r io.ReadCloser) io.ReadCloser {
@@ -170,7 +137,6 @@ type saverReadCloser struct {
 	io.Reader
 }
 
-var _ RoundTripper = SaverPerformanceHTTPTransport{}
-var _ RoundTripper = SaverMetadataHTTPTransport{}
-var _ RoundTripper = SaverBodyHTTPTransport{}
-var _ RoundTripper = SaverTransactionHTTPTransport{}
+var _ model.HTTPTransport = SaverMetadataHTTPTransport{}
+var _ model.HTTPTransport = SaverBodyHTTPTransport{}
+var _ model.HTTPTransport = SaverTransactionHTTPTransport{}
