@@ -2,11 +2,17 @@ package httptransport
 
 import (
 	"net/http"
+
+	"github.com/ooni/probe-cli/v3/internal/model"
 )
 
 // NewSystemTransport creates a new "system" HTTP transport. That is a transport
 // using the Go standard library with custom dialer and TLS dialer.
-func NewSystemTransport(config Config) RoundTripper {
+//
+// Deprecation warning
+//
+// New code should use netxlite.NewHTTPTransport instead.
+func NewSystemTransport(config Config) model.HTTPTransport {
 	txp := http.DefaultTransport.(*http.Transport).Clone()
 	txp.DialContext = config.Dialer.DialContext
 	txp.DialTLSContext = config.TLSDialer.DialTLSContext
@@ -18,7 +24,16 @@ func NewSystemTransport(config Config) RoundTripper {
 	// back the true headers, such as Content-Length. This change is
 	// functional to OONI's goal of observing the network.
 	txp.DisableCompression = true
-	return txp
+	return &SystemTransportWrapper{txp}
 }
 
-var _ RoundTripper = &http.Transport{}
+// SystemTransportWrapper adapts *http.Transport to have the .Network method
+type SystemTransportWrapper struct {
+	*http.Transport
+}
+
+func (txp *SystemTransportWrapper) Network() string {
+	return "tcp"
+}
+
+var _ model.HTTPTransport = &SystemTransportWrapper{}
