@@ -30,59 +30,24 @@ import (
 	"net/http"
 	"net/url"
 
-	"github.com/lucas-clemente/quic-go"
-	"github.com/ooni/probe-cli/v3/internal/engine/netx/bytecounter"
+	"github.com/ooni/probe-cli/v3/internal/bytecounter"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx/dialer"
-	"github.com/ooni/probe-cli/v3/internal/engine/netx/gocertifi"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx/httptransport"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx/quicdialer"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx/resolver"
-	"github.com/ooni/probe-cli/v3/internal/engine/netx/selfcensor"
+	"github.com/ooni/probe-cli/v3/internal/engine/netx/tlsdialer"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx/trace"
-	"github.com/ooni/probe-cli/v3/internal/engine/runtimex"
+	"github.com/ooni/probe-cli/v3/internal/model"
+	"github.com/ooni/probe-cli/v3/internal/netxlite"
 )
 
-// Logger is the logger assumed by this package
-type Logger interface {
-	Debugf(format string, v ...interface{})
-	Debug(message string)
-}
-
-// Dialer is the definition of dialer assumed by this package.
-type Dialer interface {
-	DialContext(ctx context.Context, network, address string) (net.Conn, error)
-}
-
-// QUICDialer is the definition of a dialer for QUIC assumed by this package.
-type QUICDialer interface {
-	Dial(network, addr string, tlsCfg *tls.Config, cfg *quic.Config) (quic.EarlySession, error)
-}
-
-// TLSDialer is the definition of a TLS dialer assumed by this package.
-type TLSDialer interface {
-	DialTLSContext(ctx context.Context, network, address string) (net.Conn, error)
-}
-
-// HTTPRoundTripper is the definition of http.HTTPRoundTripper used by this package.
-type HTTPRoundTripper interface {
-	RoundTrip(req *http.Request) (*http.Response, error)
-	CloseIdleConnections()
-}
-
-// Resolver is the interface we expect from a resolver
-type Resolver interface {
-	LookupHost(ctx context.Context, hostname string) (addrs []string, err error)
-	Network() string
-	Address() string
-}
-
 // Config contains configuration for creating a new transport. When any
 // field of Config is nil/empty, we will use a suitable default.
 //
 // We use different savers for different kind of events such that the
 // user of this library can choose what to save.
 type Config struct {
-	BaseResolver        Resolver             // default: system resolver
+	BaseResolver        model.Resolver       // default: system resolver
 	BogonIsError        bool                 // default: bogon is not error
 	ByteCounter         *bytecounter.Counter // default: no explicit byte counting
 	CacheResolutions    bool                 // default: no caching
@@ -90,18 +55,18 @@ type Config struct {
 	ContextByteCounting bool                 // default: no implicit byte counting
 	DNSCache            map[string][]string  // default: cache is empty
 	DialSaver           *trace.Saver         // default: not saving dials
-	Dialer              Dialer               // default: dialer.DNSDialer
-	FullResolver        Resolver             // default: base resolver + goodies
-	QUICDialer          QUICDialer           // default: quicdialer.DNSDialer
+	Dialer              model.Dialer         // default: dialer.DNSDialer
+	FullResolver        model.Resolver       // default: base resolver + goodies
+	QUICDialer          model.QUICDialer     // default: quicdialer.DNSDialer
 	HTTP3Enabled        bool                 // default: disabled
 	HTTPSaver           *trace.Saver         // default: not saving HTTP
-	Logger              Logger               // default: no logging
+	Logger              model.DebugLogger    // default: no logging
 	NoTLSVerify         bool                 // default: perform TLS verify
 	ProxyURL            *url.URL             // default: no proxy
 	ReadWriteSaver      *trace.Saver         // default: not saving read/write
 	ResolveSaver        *trace.Saver         // default: not saving resolves
 	TLSConfig           *tls.Config          // default: attempt using h2
-	TLSDialer           TLSDialer            // default: dialer.TLSDialer
+	TLSDialer           model.TLSDialer      // default: dialer.TLSDialer
 	TLSSaver            *trace.Saver         // default: not saving TLS
 }
 
@@ -110,23 +75,17 @@ type tlsHandshaker interface {
 		net.Conn, tls.ConnectionState, error)
 }
 
-// NewDefaultCertPool returns a copy of the default x509
-// certificate pool. This function panics on failure.
-func NewDefaultCertPool() *x509.CertPool {
-	pool, err := gocertifi.CACerts()
-	runtimex.PanicOnError(err, "gocertifi.CACerts() failed")
-	return pool
-}
-
-var defaultCertPool *x509.CertPool = NewDefaultCertPool()
+var defaultCertPool *x509.CertPool = netxlite.NewDefaultCertPool()
 
 // NewResolver creates a new resolver from the specified config
-func NewResolver(config Config) Resolver {
+func NewResolver(config Config) model.Resolver {
 	if config.BaseResolver == nil {
-		config.BaseResolver = resolver.SystemResolver{}
+		config.BaseResolver = &netxlite.ResolverSystem{}
+	}
+	var r model.Resolver = config.BaseResolver
+	r = &netxlite.AddressResolver{
+		Resolver: r,
 	}
-	var r Resolver = config.BaseResolver
-	r = resolver.AddressResolver{Resolver: r}
 	if config.CacheResolutions {
 		r = &resolver.CacheResolver{Resolver: r}
 	}
@@ -140,70 +99,74 @@ func NewResolver(config Config) Resolver {
 	if config.BogonIsError {
 		r = resolver.BogonResolver{Resolver: r}
 	}
-	r = resolver.ErrorWrapperResolver{Resolver: r}
+	r = &netxlite.ErrorWrapperResolver{Resolver: r}
 	if config.Logger != nil {
-		r = resolver.LoggingResolver{Logger: config.Logger, Resolver: r}
+		r = &netxlite.ResolverLogger{
+			Logger:   config.Logger,
+			Resolver: r,
+		}
 	}
 	if config.ResolveSaver != nil {
 		r = resolver.SaverResolver{Resolver: r, Saver: config.ResolveSaver}
 	}
-	return resolver.IDNAResolver{Resolver: r}
+	return &netxlite.ResolverIDNA{Resolver: r}
 }
 
 // NewDialer creates a new Dialer from the specified config
-func NewDialer(config Config) Dialer {
+func NewDialer(config Config) model.Dialer {
 	if config.FullResolver == nil {
 		config.FullResolver = NewResolver(config)
 	}
-	var d Dialer = selfcensor.SystemDialer{}
-	d = dialer.TimeoutDialer{Dialer: d}
-	d = dialer.ErrorWrapperDialer{Dialer: d}
-	if config.Logger != nil {
-		d = dialer.LoggingDialer{Dialer: d, Logger: config.Logger}
-	}
-	if config.DialSaver != nil {
-		d = dialer.SaverDialer{Dialer: d, Saver: config.DialSaver}
-	}
-	if config.ReadWriteSaver != nil {
-		d = dialer.SaverConnDialer{Dialer: d, Saver: config.ReadWriteSaver}
-	}
-	d = dialer.DNSDialer{Resolver: config.FullResolver, Dialer: d}
-	d = dialer.ProxyDialer{ProxyURL: config.ProxyURL, Dialer: d}
-	if config.ContextByteCounting {
-		d = dialer.ByteCounterDialer{Dialer: d}
-	}
-	d = dialer.ShapingDialer{Dialer: d}
-	return d
+	return dialer.New(&dialer.Config{
+		ContextByteCounting: config.ContextByteCounting,
+		DialSaver:           config.DialSaver,
+		Logger:              config.Logger,
+		ProxyURL:            config.ProxyURL,
+		ReadWriteSaver:      config.ReadWriteSaver,
+	}, config.FullResolver)
 }
 
 // NewQUICDialer creates a new DNS Dialer for QUIC, with the resolver from the specified config
-func NewQUICDialer(config Config) QUICDialer {
+func NewQUICDialer(config Config) model.QUICDialer {
 	if config.FullResolver == nil {
 		config.FullResolver = NewResolver(config)
 	}
-	var d quicdialer.ContextDialer = &quicdialer.SystemDialer{Saver: config.ReadWriteSaver}
-	d = quicdialer.ErrorWrapperDialer{Dialer: d}
-	if config.TLSSaver != nil {
-		d = quicdialer.HandshakeSaver{Saver: config.TLSSaver, Dialer: d}
+	var ql model.QUICListener = &netxlite.QUICListenerStdlib{}
+	ql = &netxlite.ErrorWrapperQUICListener{QUICListener: ql}
+	if config.ReadWriteSaver != nil {
+		ql = &quicdialer.QUICListenerSaver{
+			QUICListener: ql,
+			Saver:        config.ReadWriteSaver,
+		}
 	}
-	d = &quicdialer.DNSDialer{Resolver: config.FullResolver, Dialer: d}
-	var dialer QUICDialer = &httptransport.QUICWrapperDialer{Dialer: d}
-	return dialer
+	var d model.QUICDialer = &netxlite.QUICDialerQUICGo{
+		QUICListener: ql,
+	}
+	d = &netxlite.ErrorWrapperQUICDialer{
+		QUICDialer: d,
+	}
+	if config.TLSSaver != nil {
+		d = quicdialer.HandshakeSaver{Saver: config.TLSSaver, QUICDialer: d}
+	}
+	d = &netxlite.QUICDialerResolver{
+		Resolver: config.FullResolver,
+		Dialer:   d,
+	}
+	return d
 }
 
 // NewTLSDialer creates a new TLSDialer from the specified config
-func NewTLSDialer(config Config) TLSDialer {
+func NewTLSDialer(config Config) model.TLSDialer {
 	if config.Dialer == nil {
 		config.Dialer = NewDialer(config)
 	}
-	var h tlsHandshaker = dialer.SystemTLSHandshaker{}
-	h = dialer.TimeoutTLSHandshaker{TLSHandshaker: h}
-	h = dialer.ErrorWrapperTLSHandshaker{TLSHandshaker: h}
+	var h tlsHandshaker = &netxlite.TLSHandshakerConfigurable{}
+	h = &netxlite.ErrorWrapperTLSHandshaker{TLSHandshaker: h}
 	if config.Logger != nil {
-		h = dialer.LoggingTLSHandshaker{Logger: config.Logger, TLSHandshaker: h}
+		h = &netxlite.TLSHandshakerLogger{DebugLogger: config.Logger, TLSHandshaker: h}
 	}
 	if config.TLSSaver != nil {
-		h = dialer.SaverTLSHandshaker{TLSHandshaker: h, Saver: config.TLSSaver}
+		h = tlsdialer.SaverTLSHandshaker{TLSHandshaker: h, Saver: config.TLSSaver}
 	}
 	if config.TLSConfig == nil {
 		config.TLSConfig = &tls.Config{NextProtos: []string{"h2", "http/1.1"}}
@@ -213,7 +176,7 @@ func NewTLSDialer(config Config) TLSDialer {
 	}
 	config.TLSConfig.RootCAs = config.CertPool
 	config.TLSConfig.InsecureSkipVerify = config.NoTLSVerify
-	return dialer.TLSDialer{
+	return &netxlite.TLSDialerLegacy{
 		Config:        config.TLSConfig,
 		Dialer:        config.Dialer,
 		TLSHandshaker: h,
@@ -222,7 +185,7 @@ func NewTLSDialer(config Config) TLSDialer {
 
 // NewHTTPTransport creates a new HTTPRoundTripper. You can further extend the returned
 // HTTPRoundTripper before wrapping it into an http.Client.
-func NewHTTPTransport(config Config) HTTPRoundTripper {
+func NewHTTPTransport(config Config) model.HTTPTransport {
 	if config.Dialer == nil {
 		config.Dialer = NewDialer(config)
 	}
@@ -237,32 +200,28 @@ func NewHTTPTransport(config Config) HTTPRoundTripper {
 	txp := tInfo.Factory(httptransport.Config{
 		Dialer: config.Dialer, QUICDialer: config.QUICDialer, TLSDialer: config.TLSDialer,
 		TLSConfig: config.TLSConfig})
-	transport := tInfo.TransportName
 
 	if config.ByteCounter != nil {
 		txp = httptransport.ByteCountingTransport{
-			Counter: config.ByteCounter, RoundTripper: txp}
+			Counter: config.ByteCounter, HTTPTransport: txp}
 	}
 	if config.Logger != nil {
-		txp = httptransport.LoggingTransport{Logger: config.Logger, RoundTripper: txp}
+		txp = &netxlite.HTTPTransportLogger{Logger: config.Logger, HTTPTransport: txp}
 	}
 	if config.HTTPSaver != nil {
 		txp = httptransport.SaverMetadataHTTPTransport{
-			RoundTripper: txp, Saver: config.HTTPSaver, Transport: transport}
+			HTTPTransport: txp, Saver: config.HTTPSaver}
 		txp = httptransport.SaverBodyHTTPTransport{
-			RoundTripper: txp, Saver: config.HTTPSaver}
-		txp = httptransport.SaverPerformanceHTTPTransport{
-			RoundTripper: txp, Saver: config.HTTPSaver}
+			HTTPTransport: txp, Saver: config.HTTPSaver}
 		txp = httptransport.SaverTransactionHTTPTransport{
-			RoundTripper: txp, Saver: config.HTTPSaver}
+			HTTPTransport: txp, Saver: config.HTTPSaver}
 	}
-	txp = httptransport.UserAgentTransport{RoundTripper: txp}
 	return txp
 }
 
 // httpTransportInfo contains the constructing function as well as the transport name
 type httpTransportInfo struct {
-	Factory       func(httptransport.Config) httptransport.RoundTripper
+	Factory       func(httptransport.Config) model.HTTPTransport
 	TransportName string
 }
 
@@ -277,20 +236,6 @@ var allTransportsInfo = map[bool]httpTransportInfo{
 	},
 }
 
-// DNSClient is a DNS client. It wraps a Resolver and it possibly
-// also wraps an HTTP client, but only when we're using DoH.
-type DNSClient struct {
-	Resolver
-	httpClient *http.Client
-}
-
-// CloseIdleConnections closes idle connections, if any.
-func (c DNSClient) CloseIdleConnections() {
-	if c.httpClient != nil {
-		c.httpClient.CloseIdleConnections()
-	}
-}
-
 // NewDNSClient creates a new DNS client. The config argument is used to
 // create the underlying Dialer and/or HTTP transport, if needed. The URL
 // argument describes the kind of client that we want to make:
@@ -309,43 +254,14 @@ func (c DNSClient) CloseIdleConnections() {
 //
 // If config.ResolveSaver is not nil and we're creating an underlying
 // resolver where this is possible, we will also save events.
-func NewDNSClient(config Config, URL string) (DNSClient, error) {
+func NewDNSClient(config Config, URL string) (model.Resolver, error) {
 	return NewDNSClientWithOverrides(config, URL, "", "", "")
 }
 
-// ErrInvalidTLSVersion indicates that you passed us a string
-// that does not represent a valid TLS version.
-var ErrInvalidTLSVersion = errors.New("invalid TLS version")
-
-// ConfigureTLSVersion configures the correct TLS version into
-// the specified *tls.Config or returns an error.
-func ConfigureTLSVersion(config *tls.Config, version string) error {
-	switch version {
-	case "TLSv1.3":
-		config.MinVersion = tls.VersionTLS13
-		config.MaxVersion = tls.VersionTLS13
-	case "TLSv1.2":
-		config.MinVersion = tls.VersionTLS12
-		config.MaxVersion = tls.VersionTLS12
-	case "TLSv1.1":
-		config.MinVersion = tls.VersionTLS11
-		config.MaxVersion = tls.VersionTLS11
-	case "TLSv1.0", "TLSv1":
-		config.MinVersion = tls.VersionTLS10
-		config.MaxVersion = tls.VersionTLS10
-	case "":
-		// nothing
-	default:
-		return ErrInvalidTLSVersion
-	}
-	return nil
-}
-
 // NewDNSClientWithOverrides creates a new DNS client, similar to NewDNSClient,
 // with the option to override the default Hostname and SNI.
 func NewDNSClientWithOverrides(config Config, URL, hostOverride, SNIOverride,
-	TLSVersion string) (DNSClient, error) {
-	var c DNSClient
+	TLSVersion string) (model.Resolver, error) {
 	switch URL {
 	case "doh://powerdns":
 		URL = "https://doh.powerdns.org/"
@@ -358,79 +274,75 @@ func NewDNSClientWithOverrides(config Config, URL, hostOverride, SNIOverride,
 	}
 	resolverURL, err := url.Parse(URL)
 	if err != nil {
-		return c, err
+		return nil, err
 	}
 	config.TLSConfig = &tls.Config{ServerName: SNIOverride}
-	if err := ConfigureTLSVersion(config.TLSConfig, TLSVersion); err != nil {
-		return c, err
+	if err := netxlite.ConfigureTLSVersion(config.TLSConfig, TLSVersion); err != nil {
+		return nil, err
 	}
 	switch resolverURL.Scheme {
 	case "system":
-		c.Resolver = resolver.SystemResolver{}
-		return c, nil
+		return &netxlite.ResolverSystem{}, nil
 	case "https":
 		config.TLSConfig.NextProtos = []string{"h2", "http/1.1"}
-		c.httpClient = &http.Client{Transport: NewHTTPTransport(config)}
-		var txp resolver.RoundTripper = resolver.NewDNSOverHTTPSWithHostOverride(
-			c.httpClient, URL, hostOverride)
+		httpClient := &http.Client{Transport: NewHTTPTransport(config)}
+		var txp model.DNSTransport = netxlite.NewDNSOverHTTPSWithHostOverride(
+			httpClient, URL, hostOverride)
 		if config.ResolveSaver != nil {
 			txp = resolver.SaverDNSTransport{
-				RoundTripper: txp,
+				DNSTransport: txp,
 				Saver:        config.ResolveSaver,
 			}
 		}
-		c.Resolver = resolver.NewSerialResolver(txp)
-		return c, nil
+		return netxlite.NewSerialResolver(txp), nil
 	case "udp":
 		dialer := NewDialer(config)
 		endpoint, err := makeValidEndpoint(resolverURL)
 		if err != nil {
-			return c, err
+			return nil, err
 		}
-		var txp resolver.RoundTripper = resolver.NewDNSOverUDP(dialer, endpoint)
+		var txp model.DNSTransport = netxlite.NewDNSOverUDP(
+			dialer, endpoint)
 		if config.ResolveSaver != nil {
 			txp = resolver.SaverDNSTransport{
-				RoundTripper: txp,
+				DNSTransport: txp,
 				Saver:        config.ResolveSaver,
 			}
 		}
-		c.Resolver = resolver.NewSerialResolver(txp)
-		return c, nil
+		return netxlite.NewSerialResolver(txp), nil
 	case "dot":
 		config.TLSConfig.NextProtos = []string{"dot"}
 		tlsDialer := NewTLSDialer(config)
 		endpoint, err := makeValidEndpoint(resolverURL)
 		if err != nil {
-			return c, err
+			return nil, err
 		}
-		var txp resolver.RoundTripper = resolver.NewDNSOverTLS(
+		var txp model.DNSTransport = netxlite.NewDNSOverTLS(
 			tlsDialer.DialTLSContext, endpoint)
 		if config.ResolveSaver != nil {
 			txp = resolver.SaverDNSTransport{
-				RoundTripper: txp,
+				DNSTransport: txp,
 				Saver:        config.ResolveSaver,
 			}
 		}
-		c.Resolver = resolver.NewSerialResolver(txp)
-		return c, nil
+		return netxlite.NewSerialResolver(txp), nil
 	case "tcp":
 		dialer := NewDialer(config)
 		endpoint, err := makeValidEndpoint(resolverURL)
 		if err != nil {
-			return c, err
+			return nil, err
 		}
-		var txp resolver.RoundTripper = resolver.NewDNSOverTCP(
+		var txp model.DNSTransport = netxlite.NewDNSOverTCP(
 			dialer.DialContext, endpoint)
 		if config.ResolveSaver != nil {
 			txp = resolver.SaverDNSTransport{
-				RoundTripper: txp,
+				DNSTransport: txp,
 				Saver:        config.ResolveSaver,
 			}
 		}
-		c.Resolver = resolver.NewSerialResolver(txp)
-		return c, nil
+		return netxlite.NewSerialResolver(txp), nil
 	default:
-		return c, errors.New("unsupported resolver scheme")
+		return nil, errors.New("unsupported resolver scheme")
 	}
 }
 
