@@ -1,37 +1,40 @@
 package netx_test
 
 import (
+	"context"
 	"crypto/tls"
 	"errors"
+	"net"
 	"net/http"
 	"strings"
 	"testing"
 
 	"github.com/apex/log"
+	"github.com/ooni/probe-cli/v3/internal/bytecounter"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx"
-	"github.com/ooni/probe-cli/v3/internal/engine/netx/bytecounter"
-	"github.com/ooni/probe-cli/v3/internal/engine/netx/dialer"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx/httptransport"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx/resolver"
-	"github.com/ooni/probe-cli/v3/internal/engine/netx/selfcensor"
+	"github.com/ooni/probe-cli/v3/internal/engine/netx/tlsdialer"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx/trace"
+	"github.com/ooni/probe-cli/v3/internal/model/mocks"
+	"github.com/ooni/probe-cli/v3/internal/netxlite"
 )
 
 func TestNewResolverVanilla(t *testing.T) {
 	r := netx.NewResolver(netx.Config{})
-	ir, ok := r.(resolver.IDNAResolver)
+	ir, ok := r.(*netxlite.ResolverIDNA)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	ewr, ok := ir.Resolver.(resolver.ErrorWrapperResolver)
+	ewr, ok := ir.Resolver.(*netxlite.ErrorWrapperResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	ar, ok := ewr.Resolver.(resolver.AddressResolver)
+	ar, ok := ewr.Resolver.(*netxlite.AddressResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	_, ok = ar.Resolver.(resolver.SystemResolver)
+	_, ok = ar.Resolver.(*netxlite.ResolverSystem)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
@@ -43,15 +46,15 @@ func TestNewResolverSpecificResolver(t *testing.T) {
 			// not initialized because it doesn't matter in this context
 		},
 	})
-	ir, ok := r.(resolver.IDNAResolver)
+	ir, ok := r.(*netxlite.ResolverIDNA)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	ewr, ok := ir.Resolver.(resolver.ErrorWrapperResolver)
+	ewr, ok := ir.Resolver.(*netxlite.ErrorWrapperResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	ar, ok := ewr.Resolver.(resolver.AddressResolver)
+	ar, ok := ewr.Resolver.(*netxlite.AddressResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
@@ -65,11 +68,11 @@ func TestNewResolverWithBogonFilter(t *testing.T) {
 	r := netx.NewResolver(netx.Config{
 		BogonIsError: true,
 	})
-	ir, ok := r.(resolver.IDNAResolver)
+	ir, ok := r.(*netxlite.ResolverIDNA)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	ewr, ok := ir.Resolver.(resolver.ErrorWrapperResolver)
+	ewr, ok := ir.Resolver.(*netxlite.ErrorWrapperResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
@@ -77,11 +80,11 @@ func TestNewResolverWithBogonFilter(t *testing.T) {
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	ar, ok := br.Resolver.(resolver.AddressResolver)
+	ar, ok := br.Resolver.(*netxlite.AddressResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	_, ok = ar.Resolver.(resolver.SystemResolver)
+	_, ok = ar.Resolver.(*netxlite.ResolverSystem)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
@@ -91,26 +94,26 @@ func TestNewResolverWithLogging(t *testing.T) {
 	r := netx.NewResolver(netx.Config{
 		Logger: log.Log,
 	})
-	ir, ok := r.(resolver.IDNAResolver)
+	ir, ok := r.(*netxlite.ResolverIDNA)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	lr, ok := ir.Resolver.(resolver.LoggingResolver)
+	lr, ok := ir.Resolver.(*netxlite.ResolverLogger)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
 	if lr.Logger != log.Log {
 		t.Fatal("not the logger we expected")
 	}
-	ewr, ok := lr.Resolver.(resolver.ErrorWrapperResolver)
+	ewr, ok := lr.Resolver.(*netxlite.ErrorWrapperResolver)
+	if !ok {
+		t.Fatalf("not the resolver we expected")
+	}
+	ar, ok := ewr.Resolver.(*netxlite.AddressResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	ar, ok := ewr.Resolver.(resolver.AddressResolver)
-	if !ok {
-		t.Fatal("not the resolver we expected")
-	}
-	_, ok = ar.Resolver.(resolver.SystemResolver)
+	_, ok = ar.Resolver.(*netxlite.ResolverSystem)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
@@ -121,7 +124,7 @@ func TestNewResolverWithSaver(t *testing.T) {
 	r := netx.NewResolver(netx.Config{
 		ResolveSaver: saver,
 	})
-	ir, ok := r.(resolver.IDNAResolver)
+	ir, ok := r.(*netxlite.ResolverIDNA)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
@@ -132,15 +135,15 @@ func TestNewResolverWithSaver(t *testing.T) {
 	if sr.Saver != saver {
 		t.Fatal("not the saver we expected")
 	}
-	ewr, ok := sr.Resolver.(resolver.ErrorWrapperResolver)
+	ewr, ok := sr.Resolver.(*netxlite.ErrorWrapperResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	ar, ok := ewr.Resolver.(resolver.AddressResolver)
+	ar, ok := ewr.Resolver.(*netxlite.AddressResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	_, ok = ar.Resolver.(resolver.SystemResolver)
+	_, ok = ar.Resolver.(*netxlite.ResolverSystem)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
@@ -150,11 +153,11 @@ func TestNewResolverWithReadWriteCache(t *testing.T) {
 	r := netx.NewResolver(netx.Config{
 		CacheResolutions: true,
 	})
-	ir, ok := r.(resolver.IDNAResolver)
+	ir, ok := r.(*netxlite.ResolverIDNA)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	ewr, ok := ir.Resolver.(resolver.ErrorWrapperResolver)
+	ewr, ok := ir.Resolver.(*netxlite.ErrorWrapperResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
@@ -165,11 +168,11 @@ func TestNewResolverWithReadWriteCache(t *testing.T) {
 	if cr.ReadOnly != false {
 		t.Fatal("expected readwrite cache here")
 	}
-	ar, ok := cr.Resolver.(resolver.AddressResolver)
+	ar, ok := cr.Resolver.(*netxlite.AddressResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	_, ok = ar.Resolver.(resolver.SystemResolver)
+	_, ok = ar.Resolver.(*netxlite.ResolverSystem)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
@@ -181,11 +184,11 @@ func TestNewResolverWithPrefilledReadonlyCache(t *testing.T) {
 			"dns.google.com": {"8.8.8.8"},
 		},
 	})
-	ir, ok := r.(resolver.IDNAResolver)
+	ir, ok := r.(*netxlite.ResolverIDNA)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	ewr, ok := ir.Resolver.(resolver.ErrorWrapperResolver)
+	ewr, ok := ir.Resolver.(*netxlite.ErrorWrapperResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
@@ -199,294 +202,19 @@ func TestNewResolverWithPrefilledReadonlyCache(t *testing.T) {
 	if cr.Get("dns.google.com")[0] != "8.8.8.8" {
 		t.Fatal("cache not correctly prefilled")
 	}
-	ar, ok := cr.Resolver.(resolver.AddressResolver)
+	ar, ok := cr.Resolver.(*netxlite.AddressResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	_, ok = ar.Resolver.(resolver.SystemResolver)
+	_, ok = ar.Resolver.(*netxlite.ResolverSystem)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
 }
 
-func TestNewDialerVanilla(t *testing.T) {
-	d := netx.NewDialer(netx.Config{})
-	sd, ok := d.(dialer.ShapingDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	pd, ok := sd.Dialer.(dialer.ProxyDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if pd.ProxyURL != nil {
-		t.Fatal("not the proxy URL we expected")
-	}
-	dnsd, ok := pd.Dialer.(dialer.DNSDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if dnsd.Resolver == nil {
-		t.Fatal("not the resolver we expected")
-	}
-	ir, ok := dnsd.Resolver.(resolver.IDNAResolver)
-	if !ok {
-		t.Fatal("not the resolver we expected")
-	}
-	if _, ok := ir.Resolver.(resolver.ErrorWrapperResolver); !ok {
-		t.Fatal("not the resolver we expected")
-	}
-	ewd, ok := dnsd.Dialer.(dialer.ErrorWrapperDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	td, ok := ewd.Dialer.(dialer.TimeoutDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if _, ok := td.Dialer.(selfcensor.SystemDialer); !ok {
-		t.Fatal("not the dialer we expected")
-	}
-}
-
-func TestNewDialerWithResolver(t *testing.T) {
-	d := netx.NewDialer(netx.Config{
-		FullResolver: resolver.BogonResolver{
-			// not initialized because it doesn't matter in this context
-		},
-	})
-	sd, ok := d.(dialer.ShapingDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	pd, ok := sd.Dialer.(dialer.ProxyDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if pd.ProxyURL != nil {
-		t.Fatal("not the proxy URL we expected")
-	}
-	dnsd, ok := pd.Dialer.(dialer.DNSDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if dnsd.Resolver == nil {
-		t.Fatal("not the resolver we expected")
-	}
-	if _, ok := dnsd.Resolver.(resolver.BogonResolver); !ok {
-		t.Fatal("not the resolver we expected")
-	}
-	ewd, ok := dnsd.Dialer.(dialer.ErrorWrapperDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	td, ok := ewd.Dialer.(dialer.TimeoutDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if _, ok := td.Dialer.(selfcensor.SystemDialer); !ok {
-		t.Fatal("not the dialer we expected")
-	}
-}
-
-func TestNewDialerWithLogger(t *testing.T) {
-	d := netx.NewDialer(netx.Config{
-		Logger: log.Log,
-	})
-	sd, ok := d.(dialer.ShapingDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	pd, ok := sd.Dialer.(dialer.ProxyDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if pd.ProxyURL != nil {
-		t.Fatal("not the proxy URL we expected")
-	}
-	dnsd, ok := pd.Dialer.(dialer.DNSDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if dnsd.Resolver == nil {
-		t.Fatal("not the resolver we expected")
-	}
-	ir, ok := dnsd.Resolver.(resolver.IDNAResolver)
-	if !ok {
-		t.Fatal("not the resolver we expected")
-	}
-	if _, ok := ir.Resolver.(resolver.LoggingResolver); !ok {
-		t.Fatal("not the resolver we expected")
-	}
-	ld, ok := dnsd.Dialer.(dialer.LoggingDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if ld.Logger != log.Log {
-		t.Fatal("not the logger we expected")
-	}
-	ewd, ok := ld.Dialer.(dialer.ErrorWrapperDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	td, ok := ewd.Dialer.(dialer.TimeoutDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if _, ok := td.Dialer.(selfcensor.SystemDialer); !ok {
-		t.Fatal("not the dialer we expected")
-	}
-}
-
-func TestNewDialerWithDialSaver(t *testing.T) {
-	saver := new(trace.Saver)
-	d := netx.NewDialer(netx.Config{
-		DialSaver: saver,
-	})
-	sd, ok := d.(dialer.ShapingDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	pd, ok := sd.Dialer.(dialer.ProxyDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if pd.ProxyURL != nil {
-		t.Fatal("not the proxy URL we expected")
-	}
-	dnsd, ok := pd.Dialer.(dialer.DNSDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if dnsd.Resolver == nil {
-		t.Fatal("not the resolver we expected")
-	}
-	ir, ok := dnsd.Resolver.(resolver.IDNAResolver)
-	if !ok {
-		t.Fatal("not the resolver we expected")
-	}
-	if _, ok := ir.Resolver.(resolver.ErrorWrapperResolver); !ok {
-		t.Fatal("not the resolver we expected")
-	}
-	sad, ok := dnsd.Dialer.(dialer.SaverDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if sad.Saver != saver {
-		t.Fatal("not the logger we expected")
-	}
-	ewd, ok := sad.Dialer.(dialer.ErrorWrapperDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	td, ok := ewd.Dialer.(dialer.TimeoutDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if _, ok := td.Dialer.(selfcensor.SystemDialer); !ok {
-		t.Fatal("not the dialer we expected")
-	}
-}
-
-func TestNewDialerWithReadWriteSaver(t *testing.T) {
-	saver := new(trace.Saver)
-	d := netx.NewDialer(netx.Config{
-		ReadWriteSaver: saver,
-	})
-	sd, ok := d.(dialer.ShapingDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	pd, ok := sd.Dialer.(dialer.ProxyDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if pd.ProxyURL != nil {
-		t.Fatal("not the proxy URL we expected")
-	}
-	dnsd, ok := pd.Dialer.(dialer.DNSDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if dnsd.Resolver == nil {
-		t.Fatal("not the resolver we expected")
-	}
-	ir, ok := dnsd.Resolver.(resolver.IDNAResolver)
-	if !ok {
-		t.Fatal("not the resolver we expected")
-	}
-	if _, ok := ir.Resolver.(resolver.ErrorWrapperResolver); !ok {
-		t.Fatal("not the resolver we expected")
-	}
-	scd, ok := dnsd.Dialer.(dialer.SaverConnDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if scd.Saver != saver {
-		t.Fatal("not the logger we expected")
-	}
-	ewd, ok := scd.Dialer.(dialer.ErrorWrapperDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	td, ok := ewd.Dialer.(dialer.TimeoutDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if _, ok := td.Dialer.(selfcensor.SystemDialer); !ok {
-		t.Fatal("not the dialer we expected")
-	}
-}
-
-func TestNewDialerWithContextByteCounting(t *testing.T) {
-	d := netx.NewDialer(netx.Config{
-		ContextByteCounting: true,
-	})
-	sd, ok := d.(dialer.ShapingDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	bcd, ok := sd.Dialer.(dialer.ByteCounterDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	pd, ok := bcd.Dialer.(dialer.ProxyDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if pd.ProxyURL != nil {
-		t.Fatal("not the proxy URL we expected")
-	}
-	dnsd, ok := pd.Dialer.(dialer.DNSDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if dnsd.Resolver == nil {
-		t.Fatal("not the resolver we expected")
-	}
-	ir, ok := dnsd.Resolver.(resolver.IDNAResolver)
-	if !ok {
-		t.Fatal("not the resolver we expected")
-	}
-	if _, ok := ir.Resolver.(resolver.ErrorWrapperResolver); !ok {
-		t.Fatal("not the resolver we expected")
-	}
-	ewd, ok := dnsd.Dialer.(dialer.ErrorWrapperDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	td, ok := ewd.Dialer.(dialer.TimeoutDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if _, ok := td.Dialer.(selfcensor.SystemDialer); !ok {
-		t.Fatal("not the dialer we expected")
-	}
-}
-
 func TestNewTLSDialerVanilla(t *testing.T) {
 	td := netx.NewTLSDialer(netx.Config{})
-	rtd, ok := td.(dialer.TLSDialer)
+	rtd, ok := td.(*netxlite.TLSDialerLegacy)
 	if !ok {
 		t.Fatal("not the TLSDialer we expected")
 	}
@@ -502,25 +230,14 @@ func TestNewTLSDialerVanilla(t *testing.T) {
 	if rtd.Dialer == nil {
 		t.Fatal("invalid Dialer")
 	}
-	sd, ok := rtd.Dialer.(dialer.ShapingDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if _, ok := sd.Dialer.(dialer.ProxyDialer); !ok {
-		t.Fatal("not the Dialer we expected")
-	}
 	if rtd.TLSHandshaker == nil {
 		t.Fatal("invalid TLSHandshaker")
 	}
-	ewth, ok := rtd.TLSHandshaker.(dialer.ErrorWrapperTLSHandshaker)
+	ewth, ok := rtd.TLSHandshaker.(*netxlite.ErrorWrapperTLSHandshaker)
 	if !ok {
 		t.Fatal("not the TLSHandshaker we expected")
 	}
-	tth, ok := ewth.TLSHandshaker.(dialer.TimeoutTLSHandshaker)
-	if !ok {
-		t.Fatal("not the TLSHandshaker we expected")
-	}
-	if _, ok := tth.TLSHandshaker.(dialer.SystemTLSHandshaker); !ok {
+	if _, ok := ewth.TLSHandshaker.(*netxlite.TLSHandshakerConfigurable); !ok {
 		t.Fatal("not the TLSHandshaker we expected")
 	}
 }
@@ -529,7 +246,7 @@ func TestNewTLSDialerWithConfig(t *testing.T) {
 	td := netx.NewTLSDialer(netx.Config{
 		TLSConfig: new(tls.Config),
 	})
-	rtd, ok := td.(dialer.TLSDialer)
+	rtd, ok := td.(*netxlite.TLSDialerLegacy)
 	if !ok {
 		t.Fatal("not the TLSDialer we expected")
 	}
@@ -542,25 +259,14 @@ func TestNewTLSDialerWithConfig(t *testing.T) {
 	if rtd.Dialer == nil {
 		t.Fatal("invalid Dialer")
 	}
-	sd, ok := rtd.Dialer.(dialer.ShapingDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if _, ok := sd.Dialer.(dialer.ProxyDialer); !ok {
-		t.Fatal("not the Dialer we expected")
-	}
 	if rtd.TLSHandshaker == nil {
 		t.Fatal("invalid TLSHandshaker")
 	}
-	ewth, ok := rtd.TLSHandshaker.(dialer.ErrorWrapperTLSHandshaker)
+	ewth, ok := rtd.TLSHandshaker.(*netxlite.ErrorWrapperTLSHandshaker)
 	if !ok {
 		t.Fatal("not the TLSHandshaker we expected")
 	}
-	tth, ok := ewth.TLSHandshaker.(dialer.TimeoutTLSHandshaker)
-	if !ok {
-		t.Fatal("not the TLSHandshaker we expected")
-	}
-	if _, ok := tth.TLSHandshaker.(dialer.SystemTLSHandshaker); !ok {
+	if _, ok := ewth.TLSHandshaker.(*netxlite.TLSHandshakerConfigurable); !ok {
 		t.Fatal("not the TLSHandshaker we expected")
 	}
 }
@@ -569,7 +275,7 @@ func TestNewTLSDialerWithLogging(t *testing.T) {
 	td := netx.NewTLSDialer(netx.Config{
 		Logger: log.Log,
 	})
-	rtd, ok := td.(dialer.TLSDialer)
+	rtd, ok := td.(*netxlite.TLSDialerLegacy)
 	if !ok {
 		t.Fatal("not the TLSDialer we expected")
 	}
@@ -585,32 +291,21 @@ func TestNewTLSDialerWithLogging(t *testing.T) {
 	if rtd.Dialer == nil {
 		t.Fatal("invalid Dialer")
 	}
-	sd, ok := rtd.Dialer.(dialer.ShapingDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if _, ok := sd.Dialer.(dialer.ProxyDialer); !ok {
-		t.Fatal("not the Dialer we expected")
-	}
 	if rtd.TLSHandshaker == nil {
 		t.Fatal("invalid TLSHandshaker")
 	}
-	lth, ok := rtd.TLSHandshaker.(dialer.LoggingTLSHandshaker)
+	lth, ok := rtd.TLSHandshaker.(*netxlite.TLSHandshakerLogger)
 	if !ok {
 		t.Fatal("not the TLSHandshaker we expected")
 	}
-	if lth.Logger != log.Log {
+	if lth.DebugLogger != log.Log {
 		t.Fatal("not the Logger we expected")
 	}
-	ewth, ok := lth.TLSHandshaker.(dialer.ErrorWrapperTLSHandshaker)
+	ewth, ok := lth.TLSHandshaker.(*netxlite.ErrorWrapperTLSHandshaker)
 	if !ok {
 		t.Fatal("not the TLSHandshaker we expected")
 	}
-	tth, ok := ewth.TLSHandshaker.(dialer.TimeoutTLSHandshaker)
-	if !ok {
-		t.Fatal("not the TLSHandshaker we expected")
-	}
-	if _, ok := tth.TLSHandshaker.(dialer.SystemTLSHandshaker); !ok {
+	if _, ok := ewth.TLSHandshaker.(*netxlite.TLSHandshakerConfigurable); !ok {
 		t.Fatal("not the TLSHandshaker we expected")
 	}
 }
@@ -620,7 +315,7 @@ func TestNewTLSDialerWithSaver(t *testing.T) {
 	td := netx.NewTLSDialer(netx.Config{
 		TLSSaver: saver,
 	})
-	rtd, ok := td.(dialer.TLSDialer)
+	rtd, ok := td.(*netxlite.TLSDialerLegacy)
 	if !ok {
 		t.Fatal("not the TLSDialer we expected")
 	}
@@ -636,32 +331,21 @@ func TestNewTLSDialerWithSaver(t *testing.T) {
 	if rtd.Dialer == nil {
 		t.Fatal("invalid Dialer")
 	}
-	sd, ok := rtd.Dialer.(dialer.ShapingDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if _, ok := sd.Dialer.(dialer.ProxyDialer); !ok {
-		t.Fatal("not the Dialer we expected")
-	}
 	if rtd.TLSHandshaker == nil {
 		t.Fatal("invalid TLSHandshaker")
 	}
-	sth, ok := rtd.TLSHandshaker.(dialer.SaverTLSHandshaker)
+	sth, ok := rtd.TLSHandshaker.(tlsdialer.SaverTLSHandshaker)
 	if !ok {
 		t.Fatal("not the TLSHandshaker we expected")
 	}
 	if sth.Saver != saver {
 		t.Fatal("not the Logger we expected")
 	}
-	ewth, ok := sth.TLSHandshaker.(dialer.ErrorWrapperTLSHandshaker)
+	ewth, ok := sth.TLSHandshaker.(*netxlite.ErrorWrapperTLSHandshaker)
 	if !ok {
 		t.Fatal("not the TLSHandshaker we expected")
 	}
-	tth, ok := ewth.TLSHandshaker.(dialer.TimeoutTLSHandshaker)
-	if !ok {
-		t.Fatal("not the TLSHandshaker we expected")
-	}
-	if _, ok := tth.TLSHandshaker.(dialer.SystemTLSHandshaker); !ok {
+	if _, ok := ewth.TLSHandshaker.(*netxlite.TLSHandshakerConfigurable); !ok {
 		t.Fatal("not the TLSHandshaker we expected")
 	}
 }
@@ -671,7 +355,7 @@ func TestNewTLSDialerWithNoTLSVerifyAndConfig(t *testing.T) {
 		TLSConfig:   new(tls.Config),
 		NoTLSVerify: true,
 	})
-	rtd, ok := td.(dialer.TLSDialer)
+	rtd, ok := td.(*netxlite.TLSDialerLegacy)
 	if !ok {
 		t.Fatal("not the TLSDialer we expected")
 	}
@@ -687,25 +371,14 @@ func TestNewTLSDialerWithNoTLSVerifyAndConfig(t *testing.T) {
 	if rtd.Dialer == nil {
 		t.Fatal("invalid Dialer")
 	}
-	sd, ok := rtd.Dialer.(dialer.ShapingDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if _, ok := sd.Dialer.(dialer.ProxyDialer); !ok {
-		t.Fatal("not the Dialer we expected")
-	}
 	if rtd.TLSHandshaker == nil {
 		t.Fatal("invalid TLSHandshaker")
 	}
-	ewth, ok := rtd.TLSHandshaker.(dialer.ErrorWrapperTLSHandshaker)
+	ewth, ok := rtd.TLSHandshaker.(*netxlite.ErrorWrapperTLSHandshaker)
 	if !ok {
 		t.Fatal("not the TLSHandshaker we expected")
 	}
-	tth, ok := ewth.TLSHandshaker.(dialer.TimeoutTLSHandshaker)
-	if !ok {
-		t.Fatal("not the TLSHandshaker we expected")
-	}
-	if _, ok := tth.TLSHandshaker.(dialer.SystemTLSHandshaker); !ok {
+	if _, ok := ewth.TLSHandshaker.(*netxlite.TLSHandshakerConfigurable); !ok {
 		t.Fatal("not the TLSHandshaker we expected")
 	}
 }
@@ -714,7 +387,7 @@ func TestNewTLSDialerWithNoTLSVerifyAndNoConfig(t *testing.T) {
 	td := netx.NewTLSDialer(netx.Config{
 		NoTLSVerify: true,
 	})
-	rtd, ok := td.(dialer.TLSDialer)
+	rtd, ok := td.(*netxlite.TLSDialerLegacy)
 	if !ok {
 		t.Fatal("not the TLSDialer we expected")
 	}
@@ -733,36 +406,21 @@ func TestNewTLSDialerWithNoTLSVerifyAndNoConfig(t *testing.T) {
 	if rtd.Dialer == nil {
 		t.Fatal("invalid Dialer")
 	}
-	sd, ok := rtd.Dialer.(dialer.ShapingDialer)
-	if !ok {
-		t.Fatal("not the dialer we expected")
-	}
-	if _, ok := sd.Dialer.(dialer.ProxyDialer); !ok {
-		t.Fatal("not the Dialer we expected")
-	}
 	if rtd.TLSHandshaker == nil {
 		t.Fatal("invalid TLSHandshaker")
 	}
-	ewth, ok := rtd.TLSHandshaker.(dialer.ErrorWrapperTLSHandshaker)
+	ewth, ok := rtd.TLSHandshaker.(*netxlite.ErrorWrapperTLSHandshaker)
 	if !ok {
 		t.Fatal("not the TLSHandshaker we expected")
 	}
-	tth, ok := ewth.TLSHandshaker.(dialer.TimeoutTLSHandshaker)
-	if !ok {
-		t.Fatal("not the TLSHandshaker we expected")
-	}
-	if _, ok := tth.TLSHandshaker.(dialer.SystemTLSHandshaker); !ok {
+	if _, ok := ewth.TLSHandshaker.(*netxlite.TLSHandshakerConfigurable); !ok {
 		t.Fatal("not the TLSHandshaker we expected")
 	}
 }
 
 func TestNewVanilla(t *testing.T) {
 	txp := netx.NewHTTPTransport(netx.Config{})
-	uatxp, ok := txp.(httptransport.UserAgentTransport)
-	if !ok {
-		t.Fatal("not the transport we expected")
-	}
-	if _, ok := uatxp.RoundTripper.(*http.Transport); !ok {
+	if _, ok := txp.(*httptransport.SystemTransportWrapper); !ok {
 		t.Fatal("not the transport we expected")
 	}
 }
@@ -785,10 +443,17 @@ func TestNewWithDialer(t *testing.T) {
 
 func TestNewWithTLSDialer(t *testing.T) {
 	expected := errors.New("mocked error")
-	tlsDialer := dialer.TLSDialer{
-		Config:        new(tls.Config),
-		Dialer:        netx.FakeDialer{Err: expected},
-		TLSHandshaker: dialer.SystemTLSHandshaker{},
+	tlsDialer := &netxlite.TLSDialerLegacy{
+		Config: new(tls.Config),
+		Dialer: &mocks.Dialer{
+			MockDialContext: func(ctx context.Context, network string, address string) (net.Conn, error) {
+				return nil, expected
+			},
+			MockCloseIdleConnections: func() {
+				// nothing
+			},
+		},
+		TLSHandshaker: &netxlite.TLSHandshakerConfigurable{},
 	}
 	txp := netx.NewHTTPTransport(netx.Config{
 		TLSDialer: tlsDialer,
@@ -808,18 +473,14 @@ func TestNewWithByteCounter(t *testing.T) {
 	txp := netx.NewHTTPTransport(netx.Config{
 		ByteCounter: counter,
 	})
-	uatxp, ok := txp.(httptransport.UserAgentTransport)
-	if !ok {
-		t.Fatal("not the transport we expected")
-	}
-	bctxp, ok := uatxp.RoundTripper.(httptransport.ByteCountingTransport)
+	bctxp, ok := txp.(httptransport.ByteCountingTransport)
 	if !ok {
 		t.Fatal("not the transport we expected")
 	}
 	if bctxp.Counter != counter {
 		t.Fatal("not the byte counter we expected")
 	}
-	if _, ok := bctxp.RoundTripper.(*http.Transport); !ok {
+	if _, ok := bctxp.HTTPTransport.(*httptransport.SystemTransportWrapper); !ok {
 		t.Fatal("not the transport we expected")
 	}
 }
@@ -828,18 +489,14 @@ func TestNewWithLogger(t *testing.T) {
 	txp := netx.NewHTTPTransport(netx.Config{
 		Logger: log.Log,
 	})
-	uatxp, ok := txp.(httptransport.UserAgentTransport)
-	if !ok {
-		t.Fatal("not the transport we expected")
-	}
-	ltxp, ok := uatxp.RoundTripper.(httptransport.LoggingTransport)
+	ltxp, ok := txp.(*netxlite.HTTPTransportLogger)
 	if !ok {
 		t.Fatal("not the transport we expected")
 	}
 	if ltxp.Logger != log.Log {
 		t.Fatal("not the logger we expected")
 	}
-	if _, ok := ltxp.RoundTripper.(*http.Transport); !ok {
+	if _, ok := ltxp.HTTPTransport.(*httptransport.SystemTransportWrapper); !ok {
 		t.Fatal("not the transport we expected")
 	}
 }
@@ -849,39 +506,28 @@ func TestNewWithSaver(t *testing.T) {
 	txp := netx.NewHTTPTransport(netx.Config{
 		HTTPSaver: saver,
 	})
-	uatxp, ok := txp.(httptransport.UserAgentTransport)
-	if !ok {
-		t.Fatal("not the transport we expected")
-	}
-	stxptxp, ok := uatxp.RoundTripper.(httptransport.SaverTransactionHTTPTransport)
+	stxptxp, ok := txp.(httptransport.SaverTransactionHTTPTransport)
 	if !ok {
 		t.Fatal("not the transport we expected")
 	}
 	if stxptxp.Saver != saver {
 		t.Fatal("not the logger we expected")
 	}
-	sptxp, ok := stxptxp.RoundTripper.(httptransport.SaverPerformanceHTTPTransport)
-	if !ok {
-		t.Fatal("not the transport we expected")
-	}
-	if sptxp.Saver != saver {
-		t.Fatal("not the logger we expected")
-	}
-	sbtxp, ok := sptxp.RoundTripper.(httptransport.SaverBodyHTTPTransport)
+	sbtxp, ok := stxptxp.HTTPTransport.(httptransport.SaverBodyHTTPTransport)
 	if !ok {
 		t.Fatal("not the transport we expected")
 	}
 	if sbtxp.Saver != saver {
 		t.Fatal("not the logger we expected")
 	}
-	smtxp, ok := sbtxp.RoundTripper.(httptransport.SaverMetadataHTTPTransport)
+	smtxp, ok := sbtxp.HTTPTransport.(httptransport.SaverMetadataHTTPTransport)
 	if !ok {
 		t.Fatal("not the transport we expected")
 	}
 	if smtxp.Saver != saver {
 		t.Fatal("not the logger we expected")
 	}
-	if _, ok := smtxp.RoundTripper.(*http.Transport); !ok {
+	if _, ok := smtxp.HTTPTransport.(*httptransport.SystemTransportWrapper); !ok {
 		t.Fatal("not the transport we expected")
 	}
 }
@@ -891,10 +537,9 @@ func TestNewDNSClientInvalidURL(t *testing.T) {
 	if err == nil || !strings.HasSuffix(err.Error(), "invalid control character in URL") {
 		t.Fatal("not the error we expected")
 	}
-	if dnsclient.Resolver != nil {
+	if dnsclient != nil {
 		t.Fatal("expected nil resolver here")
 	}
-	dnsclient.CloseIdleConnections()
 }
 
 func TestNewDNSClientUnsupportedScheme(t *testing.T) {
@@ -902,10 +547,9 @@ func TestNewDNSClientUnsupportedScheme(t *testing.T) {
 	if err == nil || err.Error() != "unsupported resolver scheme" {
 		t.Fatal("not the error we expected")
 	}
-	if dnsclient.Resolver != nil {
+	if dnsclient != nil {
 		t.Fatal("expected nil resolver here")
 	}
-	dnsclient.CloseIdleConnections()
 }
 
 func TestNewDNSClientSystemResolver(t *testing.T) {
@@ -914,7 +558,7 @@ func TestNewDNSClientSystemResolver(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	if _, ok := dnsclient.Resolver.(resolver.SystemResolver); !ok {
+	if _, ok := dnsclient.(*netxlite.ResolverSystem); !ok {
 		t.Fatal("not the resolver we expected")
 	}
 	dnsclient.CloseIdleConnections()
@@ -926,7 +570,7 @@ func TestNewDNSClientEmpty(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	if _, ok := dnsclient.Resolver.(resolver.SystemResolver); !ok {
+	if _, ok := dnsclient.(*netxlite.ResolverSystem); !ok {
 		t.Fatal("not the resolver we expected")
 	}
 	dnsclient.CloseIdleConnections()
@@ -938,11 +582,11 @@ func TestNewDNSClientPowerdnsDoH(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	r, ok := dnsclient.Resolver.(resolver.SerialResolver)
+	r, ok := dnsclient.(*netxlite.SerialResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	if _, ok := r.Transport().(resolver.DNSOverHTTPS); !ok {
+	if _, ok := r.Transport().(*netxlite.DNSOverHTTPS); !ok {
 		t.Fatal("not the transport we expected")
 	}
 	dnsclient.CloseIdleConnections()
@@ -954,11 +598,11 @@ func TestNewDNSClientGoogleDoH(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	r, ok := dnsclient.Resolver.(resolver.SerialResolver)
+	r, ok := dnsclient.(*netxlite.SerialResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	if _, ok := r.Transport().(resolver.DNSOverHTTPS); !ok {
+	if _, ok := r.Transport().(*netxlite.DNSOverHTTPS); !ok {
 		t.Fatal("not the transport we expected")
 	}
 	dnsclient.CloseIdleConnections()
@@ -970,11 +614,11 @@ func TestNewDNSClientCloudflareDoH(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	r, ok := dnsclient.Resolver.(resolver.SerialResolver)
+	r, ok := dnsclient.(*netxlite.SerialResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	if _, ok := r.Transport().(resolver.DNSOverHTTPS); !ok {
+	if _, ok := r.Transport().(*netxlite.DNSOverHTTPS); !ok {
 		t.Fatal("not the transport we expected")
 	}
 	dnsclient.CloseIdleConnections()
@@ -987,7 +631,7 @@ func TestNewDNSClientCloudflareDoHSaver(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	r, ok := dnsclient.Resolver.(resolver.SerialResolver)
+	r, ok := dnsclient.(*netxlite.SerialResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
@@ -995,7 +639,7 @@ func TestNewDNSClientCloudflareDoHSaver(t *testing.T) {
 	if !ok {
 		t.Fatal("not the transport we expected")
 	}
-	if _, ok := txp.RoundTripper.(resolver.DNSOverHTTPS); !ok {
+	if _, ok := txp.DNSTransport.(*netxlite.DNSOverHTTPS); !ok {
 		t.Fatal("not the transport we expected")
 	}
 	dnsclient.CloseIdleConnections()
@@ -1007,11 +651,11 @@ func TestNewDNSClientUDP(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	r, ok := dnsclient.Resolver.(resolver.SerialResolver)
+	r, ok := dnsclient.(*netxlite.SerialResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	if _, ok := r.Transport().(resolver.DNSOverUDP); !ok {
+	if _, ok := r.Transport().(*netxlite.DNSOverUDP); !ok {
 		t.Fatal("not the transport we expected")
 	}
 	dnsclient.CloseIdleConnections()
@@ -1024,7 +668,7 @@ func TestNewDNSClientUDPDNSSaver(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	r, ok := dnsclient.Resolver.(resolver.SerialResolver)
+	r, ok := dnsclient.(*netxlite.SerialResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
@@ -1032,7 +676,7 @@ func TestNewDNSClientUDPDNSSaver(t *testing.T) {
 	if !ok {
 		t.Fatal("not the transport we expected")
 	}
-	if _, ok := txp.RoundTripper.(resolver.DNSOverUDP); !ok {
+	if _, ok := txp.DNSTransport.(*netxlite.DNSOverUDP); !ok {
 		t.Fatal("not the transport we expected")
 	}
 	dnsclient.CloseIdleConnections()
@@ -1044,11 +688,11 @@ func TestNewDNSClientTCP(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	r, ok := dnsclient.Resolver.(resolver.SerialResolver)
+	r, ok := dnsclient.(*netxlite.SerialResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	txp, ok := r.Transport().(resolver.DNSOverTCP)
+	txp, ok := r.Transport().(*netxlite.DNSOverTCP)
 	if !ok {
 		t.Fatal("not the transport we expected")
 	}
@@ -1065,7 +709,7 @@ func TestNewDNSClientTCPDNSSaver(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	r, ok := dnsclient.Resolver.(resolver.SerialResolver)
+	r, ok := dnsclient.(*netxlite.SerialResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
@@ -1073,7 +717,7 @@ func TestNewDNSClientTCPDNSSaver(t *testing.T) {
 	if !ok {
 		t.Fatal("not the transport we expected")
 	}
-	dotcp, ok := txp.RoundTripper.(resolver.DNSOverTCP)
+	dotcp, ok := txp.DNSTransport.(*netxlite.DNSOverTCP)
 	if !ok {
 		t.Fatal("not the transport we expected")
 	}
@@ -1089,11 +733,11 @@ func TestNewDNSClientDoT(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	r, ok := dnsclient.Resolver.(resolver.SerialResolver)
+	r, ok := dnsclient.(*netxlite.SerialResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
-	txp, ok := r.Transport().(resolver.DNSOverTCP)
+	txp, ok := r.Transport().(*netxlite.DNSOverTCP)
 	if !ok {
 		t.Fatal("not the transport we expected")
 	}
@@ -1110,7 +754,7 @@ func TestNewDNSClientDoTDNSSaver(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	r, ok := dnsclient.Resolver.(resolver.SerialResolver)
+	r, ok := dnsclient.(*netxlite.SerialResolver)
 	if !ok {
 		t.Fatal("not the resolver we expected")
 	}
@@ -1118,7 +762,7 @@ func TestNewDNSClientDoTDNSSaver(t *testing.T) {
 	if !ok {
 		t.Fatal("not the transport we expected")
 	}
-	dotls, ok := txp.RoundTripper.(resolver.DNSOverTCP)
+	dotls, ok := txp.DNSTransport.(*netxlite.DNSOverTCP)
 	if !ok {
 		t.Fatal("not the transport we expected")
 	}
@@ -1134,7 +778,7 @@ func TestNewDNSCLientDoTWithoutPort(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	if c.Resolver.Address() != "8.8.8.8:853" {
+	if c.Address() != "8.8.8.8:853" {
 		t.Fatal("expected default port to be added")
 	}
 }
@@ -1145,7 +789,7 @@ func TestNewDNSCLientTCPWithoutPort(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	if c.Resolver.Address() != "8.8.8.8:53" {
+	if c.Address() != "8.8.8.8:53" {
 		t.Fatal("expected default port to be added")
 	}
 }
@@ -1156,7 +800,7 @@ func TestNewDNSCLientUDPWithoutPort(t *testing.T) {
 	if err != nil {
 		t.Fatal(err)
 	}
-	if c.Resolver.Address() != "8.8.8.8:53" {
+	if c.Address() != "8.8.8.8:53" {
 		t.Fatal("expected default port to be added")
 	}
 }
@@ -1188,74 +832,7 @@ func TestNewDNSClientBadUDPEndpoint(t *testing.T) {
 func TestNewDNSCLientWithInvalidTLSVersion(t *testing.T) {
 	_, err := netx.NewDNSClientWithOverrides(
 		netx.Config{}, "dot://8.8.8.8", "", "", "TLSv999")
-	if !errors.Is(err, netx.ErrInvalidTLSVersion) {
+	if !errors.Is(err, netxlite.ErrInvalidTLSVersion) {
 		t.Fatalf("not the error we expected: %+v", err)
 	}
 }
-
-func TestConfigureTLSVersion(t *testing.T) {
-	tests := []struct {
-		name       string
-		version    string
-		wantErr    error
-		versionMin int
-		versionMax int
-	}{{
-		name:       "with TLSv1.3",
-		version:    "TLSv1.3",
-		wantErr:    nil,
-		versionMin: tls.VersionTLS13,
-		versionMax: tls.VersionTLS13,
-	}, {
-		name:       "with TLSv1.2",
-		version:    "TLSv1.2",
-		wantErr:    nil,
-		versionMin: tls.VersionTLS12,
-		versionMax: tls.VersionTLS12,
-	}, {
-		name:       "with TLSv1.1",
-		version:    "TLSv1.1",
-		wantErr:    nil,
-		versionMin: tls.VersionTLS11,
-		versionMax: tls.VersionTLS11,
-	}, {
-		name:       "with TLSv1.0",
-		version:    "TLSv1.0",
-		wantErr:    nil,
-		versionMin: tls.VersionTLS10,
-		versionMax: tls.VersionTLS10,
-	}, {
-		name:       "with TLSv1",
-		version:    "TLSv1",
-		wantErr:    nil,
-		versionMin: tls.VersionTLS10,
-		versionMax: tls.VersionTLS10,
-	}, {
-		name:       "with default",
-		version:    "",
-		wantErr:    nil,
-		versionMin: 0,
-		versionMax: 0,
-	}, {
-		name:       "with invalid version",
-		version:    "TLSv999",
-		wantErr:    netx.ErrInvalidTLSVersion,
-		versionMin: 0,
-		versionMax: 0,
-	}}
-	for _, tt := range tests {
-		t.Run(tt.name, func(t *testing.T) {
-			conf := new(tls.Config)
-			err := netx.ConfigureTLSVersion(conf, tt.version)
-			if !errors.Is(err, tt.wantErr) {
-				t.Fatalf("not the error we expected: %+v", err)
-			}
-			if conf.MinVersion != uint16(tt.versionMin) {
-				t.Fatalf("not the min version we expected: %+v", conf.MinVersion)
-			}
-			if conf.MaxVersion != uint16(tt.versionMax) {
-				t.Fatalf("not the max version we expected: %+v", conf.MaxVersion)
-			}
-		})
-	}
-}
