@@ -6,7 +6,7 @@ import (
 	"github.com/lucas-clemente/quic-go"
 )
 
-// ConnectionState returns the ConnectionState of a QUIC Session.
-func ConnectionState(sess quic.EarlySession) tls.ConnectionState {
+// connectionState returns the ConnectionState of a QUIC Session.
+func connectionState(sess quic.EarlySession) tls.ConnectionState {
 	return sess.ConnectionState().TLS.ConnectionState
 }
