@@ -10,23 +10,23 @@ import (
 	"os"
 	"sync"
 
-	"github.com/ooni/probe-cli/v3/internal/engine/atomicx"
+	"github.com/ooni/probe-cli/v3/internal/atomicx"
+	"github.com/ooni/probe-cli/v3/internal/bytecounter"
 	"github.com/ooni/probe-cli/v3/internal/engine/geolocate"
-	"github.com/ooni/probe-cli/v3/internal/engine/internal/platform"
 	"github.com/ooni/probe-cli/v3/internal/engine/internal/sessionresolver"
-	"github.com/ooni/probe-cli/v3/internal/engine/kvstore"
-	"github.com/ooni/probe-cli/v3/internal/engine/model"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx"
-	"github.com/ooni/probe-cli/v3/internal/engine/netx/bytecounter"
 	"github.com/ooni/probe-cli/v3/internal/engine/probeservices"
-	"github.com/ooni/probe-cli/v3/internal/engine/tunnel"
+	"github.com/ooni/probe-cli/v3/internal/kvstore"
+	"github.com/ooni/probe-cli/v3/internal/model"
+	"github.com/ooni/probe-cli/v3/internal/platform"
+	"github.com/ooni/probe-cli/v3/internal/tunnel"
 	"github.com/ooni/probe-cli/v3/internal/version"
 )
 
 // SessionConfig contains the Session config
 type SessionConfig struct {
-	AvailableProbeServices []model.Service
-	KVStore                KVStore
+	AvailableProbeServices []model.OOAPIService
+	KVStore                model.KeyValueStore
 	Logger                 model.Logger
 	ProxyURL               *url.URL
 	SoftwareName           string
@@ -48,18 +48,18 @@ type SessionConfig struct {
 // of such resources. It is not possible to reuse a Session. You MUST
 // NOT attempt to use a Session again after Session.Close.
 type Session struct {
-	availableProbeServices   []model.Service
-	availableTestHelpers     map[string][]model.Service
+	availableProbeServices   []model.OOAPIService
+	availableTestHelpers     map[string][]model.OOAPIService
 	byteCounter              *bytecounter.Counter
-	httpDefaultTransport     netx.HTTPRoundTripper
+	httpDefaultTransport     model.HTTPTransport
 	kvStore                  model.KeyValueStore
 	location                 *geolocate.Results
 	logger                   model.Logger
 	proxyURL                 *url.URL
 	queryProbeServicesCount  *atomicx.Int64
 	resolver                 *sessionresolver.Resolver
-	selectedProbeServiceHook func(*model.Service)
-	selectedProbeService     *model.Service
+	selectedProbeServiceHook func(*model.OOAPIService)
+	selectedProbeService     *model.OOAPIService
 	softwareName             string
 	softwareVersion          string
 	tempDir                  string
@@ -95,6 +95,9 @@ type Session struct {
 	// may need to pass to urlgetter when it uses a tor tunnel.
 	torBinary string
 
+	// tunnelDir is the directory used by tunnels.
+	tunnelDir string
+
 	// tunnel is the optional tunnel that we may be using. It is created
 	// by NewSession and it is cleaned up by Close.
 	tunnel tunnel.Tunnel
@@ -103,7 +106,7 @@ type Session struct {
 // sessionProbeServicesClientForCheckIn returns the probe services
 // client that we should be using for performing the check-in.
 type sessionProbeServicesClientForCheckIn interface {
-	CheckIn(ctx context.Context, config model.CheckInConfig) (*model.CheckInInfo, error)
+	CheckIn(ctx context.Context, config model.OOAPICheckInConfig) (*model.OOAPICheckInInfo, error)
 }
 
 // NewSession creates a new session. This factory function will
@@ -142,7 +145,7 @@ func NewSession(ctx context.Context, config SessionConfig) (*Session, error) {
 		return nil, errors.New("SoftwareVersion is empty")
 	}
 	if config.KVStore == nil {
-		config.KVStore = kvstore.NewMemoryKeyValueStore()
+		config.KVStore = &kvstore.Memory{}
 	}
 	// Implementation note: if config.TempDir is empty, then Go will
 	// use the temporary directory on the current system. This should
@@ -157,12 +160,13 @@ func NewSession(ctx context.Context, config SessionConfig) (*Session, error) {
 		byteCounter:             bytecounter.New(),
 		kvStore:                 config.KVStore,
 		logger:                  config.Logger,
-		queryProbeServicesCount: atomicx.NewInt64(),
+		queryProbeServicesCount: &atomicx.Int64{},
 		softwareName:            config.SoftwareName,
 		softwareVersion:         config.SoftwareVersion,
 		tempDir:                 tempDir,
 		torArgs:                 config.TorArgs,
 		torBinary:               config.TorBinary,
+		tunnelDir:               config.TunnelDir,
 	}
 	proxyURL := config.ProxyURL
 	if proxyURL != nil {
@@ -170,7 +174,7 @@ func NewSession(ctx context.Context, config SessionConfig) (*Session, error) {
 		case "psiphon", "tor", "fake":
 			config.Logger.Infof(
 				"starting '%s' tunnel; please be patient...", proxyURL.Scheme)
-			tunnel, err := tunnel.Start(ctx, &tunnel.Config{
+			tunnel, _, err := tunnel.Start(ctx, &tunnel.Config{
 				Logger:    config.Logger,
 				Name:      proxyURL.Scheme,
 				Session:   &sessionTunnelEarlySession{},
@@ -204,6 +208,11 @@ func NewSession(ctx context.Context, config SessionConfig) (*Session, error) {
 	return sess, nil
 }
 
+// TunnelDir returns the persistent directory used by tunnels.
+func (s *Session) TunnelDir() string {
+	return s.tunnelDir
+}
+
 // KibiBytesReceived accounts for the KibiBytes received by the HTTP clients
 // managed by this session so far, including experiments.
 func (s *Session) KibiBytesReceived() float64 {
@@ -243,7 +252,7 @@ func (s *Session) KibiBytesSent() float64 {
 //
 // The return value is either the check-in response or an error.
 func (s *Session) CheckIn(
-	ctx context.Context, config *model.CheckInConfig) (*model.CheckInInfo, error) {
+	ctx context.Context, config *model.OOAPICheckInConfig) (*model.OOAPICheckInInfo, error) {
 	if err := s.maybeLookupLocationContext(ctx); err != nil {
 		return nil, err
 	}
@@ -323,7 +332,7 @@ func (s *Session) doClose() {
 
 // GetTestHelpersByName returns the available test helpers that
 // use the specified name, or false if there's none.
-func (s *Session) GetTestHelpersByName(name string) ([]model.Service, bool) {
+func (s *Session) GetTestHelpersByName(name string) ([]model.OOAPIService, bool) {
 	defer s.mu.Unlock()
 	s.mu.Lock()
 	services, ok := s.availableTestHelpers[name]
@@ -337,7 +346,7 @@ func (s *Session) DefaultHTTPClient() *http.Client {
 
 // FetchTorTargets fetches tor targets from the API.
 func (s *Session) FetchTorTargets(
-	ctx context.Context, cc string) (map[string]model.TorTarget, error) {
+	ctx context.Context, cc string) (map[string]model.OOAPITorTarget, error) {
 	clnt, err := s.NewOrchestraClient(ctx)
 	if err != nil {
 		return nil, err
@@ -347,7 +356,7 @@ func (s *Session) FetchTorTargets(
 
 // FetchURLList fetches the URL list from the API.
 func (s *Session) FetchURLList(
-	ctx context.Context, config model.URLListConfig) ([]model.URLInfo, error) {
+	ctx context.Context, config model.OOAPIURLListConfig) ([]model.OOAPIURLInfo, error) {
 	clnt, err := s.NewOrchestraClient(ctx)
 	if err != nil {
 		return nil, err
@@ -576,7 +585,7 @@ func (s *Session) UserAgent() (useragent string) {
 // getAvailableProbeServicesUnlocked returns the available probe
 // services. This function WILL NOT acquire the mu mutex, therefore,
 // you MUST ensure you are using it from a locked context.
-func (s *Session) getAvailableProbeServicesUnlocked() []model.Service {
+func (s *Session) getAvailableProbeServicesUnlocked() []model.OOAPIService {
 	if len(s.availableProbeServices) > 0 {
 		return s.availableProbeServices
 	}
@@ -645,11 +654,11 @@ func (s *Session) MaybeLookupBackendsContext(ctx context.Context) error {
 // LookupLocationContext performs a location lookup. If you want memoisation
 // of the results, you should use MaybeLookupLocationContext.
 func (s *Session) LookupLocationContext(ctx context.Context) (*geolocate.Results, error) {
-	task := geolocate.Must(geolocate.NewTask(geolocate.Config{
+	task := geolocate.NewTask(geolocate.Config{
 		Logger:    s.Logger(),
 		Resolver:  s.resolver,
 		UserAgent: s.UserAgent(),
-	}))
+	})
 	return task.Run(ctx)
 }
 
